@@ -194,6 +194,7 @@ COMMIT;
 BEGIN;
 
 CREATE TABLE cc_cloud_billing_alarm (
+	plugin_id varchar(64) NOT NULL,
 	alarm_id varchar(64) NOT NULL,
 	alarm_name varchar(128) NOT NULL,
 	description varchar(256),
@@ -222,9 +223,6 @@ ALTER TABLE ONLY cc_cloud_billing_alarm
 ALTER TABLE ONLY cc_cloud_billing_alarm
     ADD CONSTRAINT f_key_cc_ccloud_billing_alarm_facility_id FOREIGN KEY (facility_id) REFERENCES cc_cfg_facility(facility_id) ON DELETE CASCADE;
 
-ALTER TABLE ONLY cc_cloud_billing_alarm
-    ADD CONSTRAINT u_key_cc_cloud_billing_alarm_facility_id UNIQUE (facility_id);
-
 COMMIT;
 
 
@@ -432,7 +430,7 @@ ALTER TABLE ONLY cc_cloud_auto_control
     ADD CONSTRAINT f_key_cc_cloud_auto_control_account_resource_id FOREIGN KEY (account_resource_id) REFERENCES cc_cloud_account_resource(account_resource_id) ON DELETE CASCADE;
 
 ALTER TABLE ONLY cc_cloud_auto_control
-    ADD CONSTRAINT f_key_cc_cloud_auto_control_facility_id FOREIGN KEY (facility_id) REFERENCES cc_cfg_node(facility_id) ON DELETE CASCADE;
+    ADD CONSTRAINT f_key_cc_cloud_auto_control_facility_id FOREIGN KEY (facility_id) REFERENCES cc_cfg_facility(facility_id) ON DELETE CASCADE;
 
 ALTER TABLE ONLY cc_cloud_auto_control
     ADD CONSTRAINT u_key_cc_cloud_auto_control_job_schedule_id UNIQUE (job_schedule_id);
