@@ -1,3 +1,15 @@
+/*
+Copyright (C) 2013 NTT DATA Corporation
+
+This program is free software; you can redistribute it and/or
+Modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation, version 2.
+
+This program is distributed in the hope that it will be
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+PURPOSE.  See the GNU General Public License for more details.
+ */
 package com.clustercontrol.cloud;
 
 import java.text.MessageFormat;
@@ -6,6 +18,8 @@ import java.util.Date;
 import java.util.List;
 import java.util.MissingResourceException;
 
+import javax.xml.bind.annotation.XmlTransient;
+
 import com.clustercontrol.cloud.bean.Image;
 import com.clustercontrol.cloud.bean.InstanceStateChange;
 import com.clustercontrol.cloud.bean.InstanceStateKind;
@@ -37,7 +51,7 @@ public interface IResourceManagement {
 
 		public String getMessage() {
 			try {
-				return Messages.getString(messageId);
+				return Messages.messages().getString(messageId);
 			}
 			catch (MissingResourceException e) {
 				return messageId;
@@ -107,6 +121,7 @@ public interface IResourceManagement {
 	
 	public static abstract class Resource {
 		private String resourceType;
+		private Object actualResource;
 		
 		public Resource() {
 		}
@@ -121,6 +136,14 @@ public interface IResourceManagement {
 		public void setResourceType(String resourceType) {
 			this.resourceType = resourceType;
 		}
+		
+		@XmlTransient
+		public Object getActualResource() {
+			return actualResource;
+		}
+		public void setActualResource(Object actualResource) {
+			this.actualResource = actualResource;
+		}
 	}
 	
 	
@@ -316,7 +339,7 @@ public interface IResourceManagement {
 			}
 
 			public int getSize() {
-				return size;
+				return size == null ? 0: size;
 			}
 			public void setSize(int size) {
 				this.size = size;
@@ -661,7 +684,8 @@ public interface IResourceManagement {
 	List<StorageBackup> getStorageBackups(List<String> storageBackupId) throws CloudManagerFault;
 
 // インスタンスバックアップ
-	InstanceBackup createInstanceBackup(String instanceId, String name, String description, Boolean withVolumes, Boolean noReboot, String backupOption) throws CloudManagerFault;
+	InstanceBackup createInstanceBackup(String instanceId, String name, String description, Boolean noReboot, String backupOption) throws CloudManagerFault;
+	InstanceBackup createInstanceBackup(String instanceId, String name, String description, Boolean noReboot, List<String> strageIds, String backupOption) throws CloudManagerFault;
 	void deleteInstanceBackup(String instanceBackupId) throws CloudManagerFault;
 	InstanceBackup getInstanceBackup(String instanceBackupId) throws CloudManagerFault;
 	List<InstanceBackup> getInstanceBackups(String...instanceBackupIds) throws CloudManagerFault;
