@@ -1,3 +1,15 @@
+/*
+Copyright (C) 2013 NTT DATA Corporation
+
+This program is free software; you can redistribute it and/or
+Modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation, version 2.
+
+This program is distributed in the hope that it will be
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+PURPOSE.  See the GNU General Public License for more details.
+ */
 package com.clustercontrol.cloud.aws.factory;
 
 import java.util.ArrayList;
@@ -47,6 +59,7 @@ import com.amazonaws.services.ec2.model.TerminateInstancesRequest;
 import com.amazonaws.services.ec2.model.Volume;
 import com.amazonaws.services.ec2.model.VolumeType;
 import com.amazonaws.services.elasticloadbalancing.AmazonElasticLoadBalancing;
+import com.amazonaws.services.elasticloadbalancing.model.DeregisterInstancesFromLoadBalancerRequest;
 import com.amazonaws.services.elasticloadbalancing.model.DescribeLoadBalancersRequest;
 import com.amazonaws.services.elasticloadbalancing.model.DescribeLoadBalancersResult;
 import com.amazonaws.services.elasticloadbalancing.model.LoadBalancerDescription;
@@ -186,7 +199,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 			.withImageId(imageId)
 			.withMonitoring(detail.monitoring)
 			.withKeyName(detail.keyName)
-			.withPlacement(new Placement().withAvailabilityZone(zone))
+			.withPlacement(new Placement().withAvailabilityZone(detail.subnetId == null ? zone: null))
 			.withDisableApiTermination(detail.disableApiTermination)
 			.withSubnetId(detail.subnetId)
 			.withMinCount(1)
@@ -369,6 +382,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 			cloudTags.add(new Tag(tag.getKey(), tag.getValue()));
 		}
 		instance.setTags(cloudTags);
+		instance.setActualResource(awsInstance);
 
 		return instance;
 	}
@@ -402,7 +416,13 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 	public List<Instance> getInstances(List<String> instanceIds) throws CloudManagerFault {
 		try {
 			AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
-			DescribeInstancesResult result = ec2.describeInstances(new DescribeInstancesRequest().withInstanceIds(instanceIds));
+			DescribeInstancesResult result = null;
+			if (instanceIds.isEmpty()) {
+				result = ec2.describeInstances();
+			}
+			else {
+				result = ec2.describeInstances(new DescribeInstancesRequest().withFilters(new com.amazonaws.services.ec2.model.Filter("instance-id", instanceIds)));
+			}
 
 			List<Instance> instances = new ArrayList<>();
 			for (Reservation r: result.getReservations()) {
@@ -743,6 +763,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 			}
 
 			storage.setCreateTime(volume.getCreateTime());
+			storage.setActualResource(volume);
 
 			return storage;
 		}
@@ -766,7 +787,14 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 	public List<Storage> getStorages(List<String> storageIds) throws CloudManagerFault {
 		try {
 			AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
-			DescribeVolumesResult result = ec2.describeVolumes(new DescribeVolumesRequest().withVolumeIds(storageIds));
+			
+			DescribeVolumesResult result = null;
+			if (storageIds.isEmpty()) {
+				result = ec2.describeVolumes();
+			}
+			else {
+				result = ec2.describeVolumes(new DescribeVolumesRequest().withFilters(new com.amazonaws.services.ec2.model.Filter("volume-id", storageIds)));
+			}
 
 			List<Storage> storages = new ArrayList<>();
 			for (Volume volume: result.getVolumes()) {
@@ -798,6 +826,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 					break;
 				}
 				storage.setCreateTime(volume.getCreateTime());
+				storage.setActualResource(volume);
 				storages.add(storage);
 			}
 
@@ -877,6 +906,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 			storageBackup.getBackupedData().setZone(backupedData.zone);
 			storageBackup.getBackupedData().setSize(backupedData.size);
 			storageBackup.getBackupedData().setStorageDetail(om.writerWithType(StorageDetail.class).writeValueAsString(backupedData.storageDetail));
+			storageBackup.setActualResource(createSnapshotResult.getSnapshot());
 
 			//			success = true;
 
@@ -970,147 +1000,6 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 		return snapshots;
 	}
 
-	@Override
-	public InstanceBackup createInstanceBackup(String instanceId, String name, String description, Boolean withVolumes, Boolean noReboot, String backupOption) throws CloudManagerFault {
-		AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
-		String imageId = null;
-		//		boolean success = false;
-		try {
-			// AWS イメージ作成。
-			CreateImageRequest createImageRequest = new CreateImageRequest()
-			.withInstanceId(instanceId)
-			.withName(name)
-			.withDescription(description)
-			.withNoReboot(noReboot != null ? noReboot: false);
-
-			// ルートデバイス以外のストレージをバックアップ対象にするか判定。
-			if (!Boolean.TRUE.equals(withVolumes)) {
-				// ルートデバイス名取得。
-				com.amazonaws.services.ec2.model.DescribeInstancesRequest request = new com.amazonaws.services.ec2.model.DescribeInstancesRequest().withInstanceIds(instanceId);
-				com.amazonaws.services.ec2.model.Instance instance = ec2.describeInstances(request).getReservations().get(0).getInstances().get(0);
-
-				// ルートデバイス以外のデバイスの情報を取得。
-				List<com.amazonaws.services.ec2.model.BlockDeviceMapping> blockDeviceMappings = new ArrayList<>();
-				for (InstanceBlockDeviceMapping instanceBlockDeviceMapping: instance.getBlockDeviceMappings()) {
-					if (instanceBlockDeviceMapping.getDeviceName().equals(instance.getRootDeviceName())) {
-						continue;
-					}
-
-					com.amazonaws.services.ec2.model.BlockDeviceMapping blockDeviceMapping = new com.amazonaws.services.ec2.model.BlockDeviceMapping();
-					blockDeviceMapping.setDeviceName(instanceBlockDeviceMapping.getDeviceName());
-					blockDeviceMapping.setNoDevice("");
-					blockDeviceMappings.add(blockDeviceMapping);
-				}
-				createImageRequest.setBlockDeviceMappings(blockDeviceMappings);
-			}
-
-			// AWS イメージ作成。
-			CreateImageResult createImageResult = ec2.createImage(createImageRequest);
-			imageId = createImageResult.getImageId();
-			AWSUtil.addTags(ec2, createImageResult.getImageId(), new com.amazonaws.services.ec2.model.Tag(KEY_NAME, imageId), new com.amazonaws.services.ec2.model.Tag("SouceInstanceId", instanceId));
-
-			final com.amazonaws.services.ec2.model.Image image = ec2.describeImages(new com.amazonaws.services.ec2.model.DescribeImagesRequest().withImageIds(imageId)).getImages().get(0);
-			if (image.getState().equals("failed")) {
-				ec2.deregisterImage(new DeregisterImageRequest().withImageId(imageId));
-				throw ErrorCode.Resource_Instance_Backup_Image_State_Failed.cloudManagerFault();
-			}
-
-			SessionService.current().addRollbackAction(
-					new SessionService.RolebackAction() {
-						@Override
-						public void rollback() throws TransactionException {
-							try {
-								AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
-								com.amazonaws.services.ec2.model.DeregisterImageRequest deregisterImageRequest = new com.amazonaws.services.ec2.model.DeregisterImageRequest().withImageId(image.getImageId());
-								ec2.deregisterImage(deregisterImageRequest);
-							}
-							catch (CloudManagerFault e) {
-								throw new TransactionException(e);
-							}
-						}
-					}
-					);
-
-			com.amazonaws.services.ec2.model.Instance instance = ec2.describeInstances(new com.amazonaws.services.ec2.model.DescribeInstancesRequest().withInstanceIds(instanceId)).getReservations().get(0).getInstances().get(0);
-
-			BackupedInstanceDetail backupedData = new BackupedInstanceDetail();
-			backupedData.instanceId = instanceId;
-			for (com.amazonaws.services.ec2.model.Tag t: instance.getTags()) {
-				if (KEY_NAME.equals(t.getKey())) {
-					backupedData.name = t.getValue();
-					break;
-				}
-			}
-			backupedData.flavor = instance.getInstanceType();
-			backupedData.zone = instance.getPlacement().getAvailabilityZone();
-			backupedData.tags = new ArrayList<>();
-			backupedData.createTime = new Date();
-			for (com.amazonaws.services.ec2.model.Tag t: instance.getTags()) {
-				if (KEY_NAME.equals(t.getKey())) continue;
-				backupedData.tags.add(new Tag(t.getKey(), t.getValue()));
-			}
-			backupedData.instanceDetail = new InstanceDetail();
-			backupedData.instanceDetail.subnetId = instance.getSubnetId();
-			backupedData.instanceDetail.securityGroupIds = new ArrayList<>(instance.getSecurityGroups().size());
-			for (GroupIdentifier gi: instance.getSecurityGroups()) {
-				backupedData.instanceDetail.securityGroupIds.add(gi.getGroupId());
-			}
-			backupedData.instanceDetail.keyName = instance.getKeyName();
-			backupedData.instanceDetail.monitoring = instance.getMonitoring().getState().equals("enabled");
-			backupedData.instanceDetail.disableApiTermination = ec2.describeInstanceAttribute(new DescribeInstanceAttributeRequest().withInstanceId(instanceId).withAttribute(InstanceAttributeName.DisableApiTermination)).getInstanceAttribute().getDisableApiTermination();
-			backupedData.instanceDetail.instanceInitiatedShutdownBehavior = ec2.describeInstanceAttribute(new DescribeInstanceAttributeRequest().withInstanceId(instanceId).withAttribute(InstanceAttributeName.InstanceInitiatedShutdownBehavior)).getInstanceAttribute().getInstanceInitiatedShutdownBehavior();
-			backupedData.instanceDetail.ebsOptimized = instance.isEbsOptimized();
-			backupedData.instanceDetail.rootBlockDevice = new EbsBlockDevice();
-			for (InstanceBlockDeviceMapping device: instance.getBlockDeviceMappings()) {
-				if (device.getDeviceName().equals(instance.getRootDeviceName()) &&  device.getEbs() != null) {
-					Volume v = ec2.describeVolumes(new DescribeVolumesRequest().withVolumeIds(device.getEbs().getVolumeId())).getVolumes().get(0);
-					backupedData.instanceDetail.rootBlockDevice.volumeType = v.getVolumeType();
-					backupedData.instanceDetail.rootBlockDevice.volumeSize = v.getSize();
-					backupedData.instanceDetail.rootBlockDevice.iops = v.getIops();
-					backupedData.instanceDetail.rootBlockDevice.deleteOnTermination = device.getEbs().getDeleteOnTermination();
-				}
-			}
-
-			ObjectMapper om = new ObjectMapper();
-			ObjectWriter ow = om.writerWithType(BackupedInstanceDetail.class);
-			String backupedDetail = ow.writeValueAsString(backupedData);
-			store.put(RT_InstanceBackup, imageId, backupedDetail);
-
-			final InstanceBackup instanceBackup = new InstanceBackup();
-			instanceBackup.setResourceType(RT_InstanceBackup);
-			instanceBackup.setInstanceBackupId(imageId);
-			instanceBackup.setName(name);
-			instanceBackup.setDescription(description);
-			instanceBackup.setInstanceId(instanceId);
-			instanceBackup.setPlatform(instance.getPlatform() == null ? PlatformKind.linux: PlatformKind.windows);
-			instanceBackup.setCreateTime(backupedData.createTime);
-			instanceBackup.setBackupedData(new InstanceBackup.BackupedData());
-			instanceBackup.getBackupedData().setName(backupedData.name);
-			instanceBackup.getBackupedData().setFlavor(backupedData.flavor);
-			instanceBackup.getBackupedData().setZone(backupedData.zone);
-			instanceBackup.getBackupedData().setTags(backupedData.tags);
-			instanceBackup.getBackupedData().setInstanceDetail(om.writerWithType(InstanceDetail.class).writeValueAsString(backupedData.instanceDetail));
-
-			//			success = true;
-
-			return instanceBackup;
-		}
-		catch (AmazonServiceException e) {
-			throw new CloudManagerFault(e.getMessage(), e.getErrorCode(), e);
-		}
-		catch (Exception e) {
-			throw new InternalManagerError(e);
-		}
-		finally {
-			//			if (!success) {
-			//				if (imageId != null) {
-			//					com.amazonaws.services.ec2.model.DeregisterImageRequest deregisterImageRequest = new com.amazonaws.services.ec2.model.DeregisterImageRequest().withImageId(imageId);
-			//					ec2.deregisterImage(deregisterImageRequest);
-			//				}
-			//			}
-		}
-	}
-
 	@Override
 	public void deleteInstanceBackup(String instanceBackupId) throws CloudManagerFault {
 		AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
@@ -1190,6 +1079,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 			image.setName(awsImage.getName());
 			image.setImageId(awsImage.getImageId());
 			image.setDescription(awsImage.getDescription());
+			image.setActualResource(awsImage);
 			images.add(image);
 		}
 		return images;
@@ -1345,6 +1235,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 				storageBackup.getBackupedData().setFlavor(backuped.flavor);
 				storageBackup.getBackupedData().setZone(backuped.zone);
 				storageBackup.getBackupedData().setStorageDetail(ow.writeValueAsString(backuped.storageDetail));
+				storageBackup.setActualResource(snapshot);
 
 				return storageBackup;
 			}
@@ -1379,18 +1270,23 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 			ObjectWriter ow = om.writerWithType(StorageDetail.class);
 
 			AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
-			com.amazonaws.services.ec2.model.DescribeSnapshotsResult result = ec2.describeSnapshots(new com.amazonaws.services.ec2.model.DescribeSnapshotsRequest().withSnapshotIds(storageBackupIds));
-
+			com.amazonaws.services.ec2.model.DescribeSnapshotsResult result = null;
+			if (storageBackupIds.isEmpty()) {
+				result = ec2.describeSnapshots(new com.amazonaws.services.ec2.model.DescribeSnapshotsRequest());
+			}
+			else {
+				result = ec2.describeSnapshots(new com.amazonaws.services.ec2.model.DescribeSnapshotsRequest().withFilters(new com.amazonaws.services.ec2.model.Filter("snapshot-id", storageBackupIds)));
+			}
 			List<String> storageBackupIdsList = storageBackupIds.isEmpty() ? store.getIds(RT_StorageBackup): new ArrayList<>(storageBackupIds);
 			List<StorageBackup> storageBackups = new ArrayList<>();
 			for (com.amazonaws.services.ec2.model.Snapshot snapshot: result.getSnapshots()) {
-				for (Iterator<String> iter = storageBackupIdsList.iterator(); iter.hasNext();) {
-					if (iter.next().equals(snapshot.getSnapshotId())) {
-						iter.remove();
-						break;
-					}
+				if (storageBackupIdsList.contains(snapshot.getSnapshotId())) {
+					storageBackupIdsList.remove(snapshot.getSnapshotId());
 				}
-
+				else {
+					continue;
+				}
+				
 				if (!"error".equals(snapshot.getState())) {
 					String backupDetail = store.get(RT_StorageBackup, snapshot.getSnapshotId());
 					BackupedStorageDetail backuped = or.readValue(backupDetail);
@@ -1413,6 +1309,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 					storageBackup.getBackupedData().setZone(backuped.zone);
 					storageBackup.getBackupedData().setSize(backuped.size);
 					storageBackup.getBackupedData().setStorageDetail(ow.writeValueAsString(backuped.storageDetail));
+					storageBackup.setActualResource(snapshot);
 
 					storageBackups.add(storageBackup);
 				}
@@ -1483,7 +1380,8 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 
 				ObjectWriter ow = om.writerWithType(InstanceDetail.class);
 				instanceBackup.getBackupedData().setInstanceDetail(ow.writeValueAsString(backuped.instanceDetail));
-
+				instanceBackup.setActualResource(image);
+				
 				return instanceBackup;
 			}
 			else {
@@ -1518,8 +1416,14 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 			ObjectWriter ow = om.writerWithType(InstanceDetail.class);
 
 			AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
-			com.amazonaws.services.ec2.model.DescribeImagesResult result = ec2.describeImages(new com.amazonaws.services.ec2.model.DescribeImagesRequest().withImageIds(instanceBackupIds));
-
+			com.amazonaws.services.ec2.model.DescribeImagesResult result = null;
+			if (instanceBackupIds.isEmpty()) {
+				result = ec2.describeImages();
+			}
+			else {
+				result = ec2.describeImages(new com.amazonaws.services.ec2.model.DescribeImagesRequest().withFilters(new com.amazonaws.services.ec2.model.Filter("image-id", instanceBackupIds)));
+			}
+			
 			List<String> instanceBackupIdsList = instanceBackupIds.isEmpty() ? store.getIds(RT_InstanceBackup): new ArrayList<>(instanceBackupIds);
 			List<InstanceBackup> instanceBackups = new ArrayList<>();
 			for (com.amazonaws.services.ec2.model.Image image: result.getImages()) {
@@ -1553,6 +1457,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 					instanceBackup.getBackupedData().setZone(backuped.zone);
 					instanceBackup.getBackupedData().setTags(backuped.tags);
 					instanceBackup.getBackupedData().setInstanceDetail(ow.writeValueAsString(backuped.instanceDetail));
+					instanceBackup.setActualResource(image);
 
 					instanceBackups.add(instanceBackup);
 				}
@@ -1636,6 +1541,7 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 					}
 				}
 			}
+			lb.setActualResource(description);
 			lbs.add(lb);
 		}
 		return lbs;
@@ -1676,20 +1582,154 @@ public class AWSResourceManagement implements IResourceManagement, AWSConstants
 		}
 
 		LoadBalancerDescription description = elbResult.getLoadBalancerDescriptions().get(0);
-		RegisterInstancesWithLoadBalancerRequest regRequest = new RegisterInstancesWithLoadBalancerRequest().withLoadBalancerName(lbId);
+		DeregisterInstancesFromLoadBalancerRequest regRequest = new DeregisterInstancesFromLoadBalancerRequest().withLoadBalancerName(lbId);
 		for (com.amazonaws.services.elasticloadbalancing.model.Instance i: description.getInstances()) {
 			if (i.getInstanceId().equals(instanceId)) {
-				continue;
+				regRequest.getInstances().add(i);
+				break;
 			}
-			regRequest.getInstances().add(i);
 		}
 
-		if (description.getInstances().size() == regRequest.getInstances().size()) {
+		if (regRequest.getInstances().isEmpty()) {
 			// 削除対象のインスタンスが登録されていないので終了。
 			return;
 		}
+		elb.deregisterInstancesFromLoadBalancer(regRequest);
+	}
 
-		regRequest.getInstances().add(new com.amazonaws.services.elasticloadbalancing.model.Instance(instanceId));
-		elb.registerInstancesWithLoadBalancer(regRequest);
+	@Override
+	public InstanceBackup createInstanceBackup(String instanceId, String name, String description, Boolean noReboot, String backupOption) throws CloudManagerFault {
+		return createInstanceBackup(instanceId, name, description, noReboot, null, backupOption);
+	}
+
+	@Override
+	public InstanceBackup createInstanceBackup(String instanceId, String name, String description, Boolean noReboot, List<String> storageIds, String backupOption) throws CloudManagerFault {
+		AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
+		String imageId = null;
+		try {
+			// AWS イメージ作成。
+			CreateImageRequest createImageRequest = new CreateImageRequest()
+				.withInstanceId(instanceId)
+				.withName(name)
+				.withDescription(description)
+				.withNoReboot(noReboot != null ? noReboot: false);
+
+			// ルートデバイス以外のストレージをバックアップ対象にするか判定。
+			if (storageIds != null) {
+				// ルートデバイス名取得。
+				com.amazonaws.services.ec2.model.DescribeInstancesRequest request = new com.amazonaws.services.ec2.model.DescribeInstancesRequest().withInstanceIds(instanceId);
+				com.amazonaws.services.ec2.model.Instance instance = ec2.describeInstances(request).getReservations().get(0).getInstances().get(0);
+
+				// ルートデバイス以外のデバイスの情報を取得。
+				List<com.amazonaws.services.ec2.model.BlockDeviceMapping> blockDeviceMappings = new ArrayList<>();
+				for (InstanceBlockDeviceMapping instanceBlockDeviceMapping: instance.getBlockDeviceMappings()) {
+					if (!instanceBlockDeviceMapping.getDeviceName().equals(instance.getRootDeviceName()) && instanceBlockDeviceMapping.getEbs() != null) {
+						if (storageIds.contains(instanceBlockDeviceMapping.getEbs().getVolumeId())) continue;
+						
+						com.amazonaws.services.ec2.model.BlockDeviceMapping blockDeviceMapping = new com.amazonaws.services.ec2.model.BlockDeviceMapping();
+						blockDeviceMapping.setDeviceName(instanceBlockDeviceMapping.getDeviceName());
+						blockDeviceMapping.setNoDevice("");
+						blockDeviceMappings.add(blockDeviceMapping);
+					}
+				}
+				createImageRequest.setBlockDeviceMappings(blockDeviceMappings);
+			}
+
+			// AWS イメージ作成。
+			CreateImageResult createImageResult = ec2.createImage(createImageRequest);
+			imageId = createImageResult.getImageId();
+			AWSUtil.addTags(ec2, createImageResult.getImageId(), new com.amazonaws.services.ec2.model.Tag(KEY_NAME, imageId), new com.amazonaws.services.ec2.model.Tag("SouceInstanceId", instanceId));
+
+			final com.amazonaws.services.ec2.model.Image image = ec2.describeImages(new com.amazonaws.services.ec2.model.DescribeImagesRequest().withImageIds(imageId)).getImages().get(0);
+			if (image.getState().equals("failed")) {
+				ec2.deregisterImage(new DeregisterImageRequest().withImageId(imageId));
+				throw ErrorCode.Resource_Instance_Backup_Image_State_Failed.cloudManagerFault();
+			}
+
+			SessionService.current().addRollbackAction(
+					new SessionService.RolebackAction() {
+						@Override
+						public void rollback() throws TransactionException {
+							try {
+								AmazonEC2 ec2 = AWSUtil.createAmazonEC2(credential, region.getEndpoint(EP_TYPE_EC2).getLocation());
+								com.amazonaws.services.ec2.model.DeregisterImageRequest deregisterImageRequest = new com.amazonaws.services.ec2.model.DeregisterImageRequest().withImageId(image.getImageId());
+								ec2.deregisterImage(deregisterImageRequest);
+							}
+							catch (CloudManagerFault e) {
+								throw new TransactionException(e);
+							}
+						}
+					}
+					);
+
+			com.amazonaws.services.ec2.model.Instance instance = ec2.describeInstances(new com.amazonaws.services.ec2.model.DescribeInstancesRequest().withInstanceIds(instanceId)).getReservations().get(0).getInstances().get(0);
+
+			BackupedInstanceDetail backupedData = new BackupedInstanceDetail();
+			backupedData.instanceId = instanceId;
+			for (com.amazonaws.services.ec2.model.Tag t: instance.getTags()) {
+				if (KEY_NAME.equals(t.getKey())) {
+					backupedData.name = t.getValue();
+					break;
+				}
+			}
+			backupedData.flavor = instance.getInstanceType();
+			backupedData.zone = instance.getPlacement().getAvailabilityZone();
+			backupedData.tags = new ArrayList<>();
+			backupedData.createTime = new Date();
+			for (com.amazonaws.services.ec2.model.Tag t: instance.getTags()) {
+				if (KEY_NAME.equals(t.getKey())) continue;
+				backupedData.tags.add(new Tag(t.getKey(), t.getValue()));
+			}
+			backupedData.instanceDetail = new InstanceDetail();
+			backupedData.instanceDetail.subnetId = instance.getSubnetId();
+			backupedData.instanceDetail.securityGroupIds = new ArrayList<>(instance.getSecurityGroups().size());
+			for (GroupIdentifier gi: instance.getSecurityGroups()) {
+				backupedData.instanceDetail.securityGroupIds.add(gi.getGroupId());
+			}
+			backupedData.instanceDetail.keyName = instance.getKeyName();
+			backupedData.instanceDetail.monitoring = instance.getMonitoring().getState().equals("enabled");
+			backupedData.instanceDetail.disableApiTermination = ec2.describeInstanceAttribute(new DescribeInstanceAttributeRequest().withInstanceId(instanceId).withAttribute(InstanceAttributeName.DisableApiTermination)).getInstanceAttribute().getDisableApiTermination();
+			backupedData.instanceDetail.instanceInitiatedShutdownBehavior = ec2.describeInstanceAttribute(new DescribeInstanceAttributeRequest().withInstanceId(instanceId).withAttribute(InstanceAttributeName.InstanceInitiatedShutdownBehavior)).getInstanceAttribute().getInstanceInitiatedShutdownBehavior();
+			backupedData.instanceDetail.ebsOptimized = instance.isEbsOptimized();
+			backupedData.instanceDetail.rootBlockDevice = new EbsBlockDevice();
+			for (InstanceBlockDeviceMapping device: instance.getBlockDeviceMappings()) {
+				if (device.getDeviceName().equals(instance.getRootDeviceName()) &&  device.getEbs() != null) {
+					Volume v = ec2.describeVolumes(new DescribeVolumesRequest().withVolumeIds(device.getEbs().getVolumeId())).getVolumes().get(0);
+					backupedData.instanceDetail.rootBlockDevice.volumeType = v.getVolumeType();
+					backupedData.instanceDetail.rootBlockDevice.volumeSize = v.getSize();
+					backupedData.instanceDetail.rootBlockDevice.iops = v.getIops();
+					backupedData.instanceDetail.rootBlockDevice.deleteOnTermination = device.getEbs().getDeleteOnTermination();
+				}
+			}
+
+			ObjectMapper om = new ObjectMapper();
+			ObjectWriter ow = om.writerWithType(BackupedInstanceDetail.class);
+			String backupedDetail = ow.writeValueAsString(backupedData);
+			store.put(RT_InstanceBackup, imageId, backupedDetail);
+
+			final InstanceBackup instanceBackup = new InstanceBackup();
+			instanceBackup.setResourceType(RT_InstanceBackup);
+			instanceBackup.setInstanceBackupId(imageId);
+			instanceBackup.setName(name);
+			instanceBackup.setDescription(description);
+			instanceBackup.setInstanceId(instanceId);
+			instanceBackup.setPlatform(instance.getPlatform() == null ? PlatformKind.linux: PlatformKind.windows);
+			instanceBackup.setCreateTime(backupedData.createTime);
+			instanceBackup.setBackupedData(new InstanceBackup.BackupedData());
+			instanceBackup.getBackupedData().setName(backupedData.name);
+			instanceBackup.getBackupedData().setFlavor(backupedData.flavor);
+			instanceBackup.getBackupedData().setZone(backupedData.zone);
+			instanceBackup.getBackupedData().setTags(backupedData.tags);
+			instanceBackup.getBackupedData().setInstanceDetail(om.writerWithType(InstanceDetail.class).writeValueAsString(backupedData.instanceDetail));
+			instanceBackup.setActualResource(image);
+
+			return instanceBackup;
+		}
+		catch (AmazonServiceException e) {
+			throw new CloudManagerFault(e.getMessage(), e.getErrorCode(), e);
+		}
+		catch (Exception e) {
+			throw new InternalManagerError(e);
+		}
 	}
 }
\ No newline at end of file
