@@ -13,14 +13,15 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.cloud.factory;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import javax.persistence.EntityExistsException;
+import javax.persistence.Query;
 
 import org.apache.log4j.Logger;
 
@@ -32,13 +33,13 @@ import com.clustercontrol.cloud.IResourceManagement.Instance;
 import com.clustercontrol.cloud.IResourceManagement.Instance.BlockDeviceMapping;
 import com.clustercontrol.cloud.IResourceManagement.InstanceBackup;
 import com.clustercontrol.cloud.MessagesHolder;
-import com.clustercontrol.cloud.PluginFault;
 import com.clustercontrol.cloud.SessionService;
 import com.clustercontrol.cloud.SessionService.RolebackAction;
 import com.clustercontrol.cloud.bean.CloudInstance;
 import com.clustercontrol.cloud.bean.CloudInstanceBackup;
 import com.clustercontrol.cloud.bean.CloudTemplate;
 import com.clustercontrol.cloud.bean.CreateInstanceBackupRequest;
+import com.clustercontrol.cloud.bean.CreateInstanceBackupRequest2;
 import com.clustercontrol.cloud.bean.CreateInstanceByTemplateRequest;
 import com.clustercontrol.cloud.bean.CreateInstanceRequest;
 import com.clustercontrol.cloud.bean.Image;
@@ -64,8 +65,6 @@ import com.clustercontrol.cloud.persistence.EntityManagerEx;
 import com.clustercontrol.cloud.persistence.PersistenceUtil.TransactionScope;
 import com.clustercontrol.cloud.persistence.TransactionException;
 import com.clustercontrol.cloud.persistence.Transactional;
-import com.clustercontrol.cloud.registry.IObjectChangedService;
-import com.clustercontrol.cloud.registry.ObjectRegistryService;
 import com.clustercontrol.cloud.util.AccountResourceUtil;
 import com.clustercontrol.cloud.util.CloudMessageUtil;
 import com.clustercontrol.cloud.util.HinemosUtil;
@@ -76,85 +75,12 @@ import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.InvalidSetting;
 import com.clustercontrol.fault.UsedFacility;
-import com.clustercontrol.hinemosagent.util.AgentConnectUtil;
 import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 
 @Transactional
 public class InstanceOperator extends ResourceOperatorBase implements IInstanceOperator {
 	
-	public static class AddedEventNotifier<T> implements AutoCloseable {
-		private String type;
-		private Class<T> clazz;
-		private T object;
-		
-		public AddedEventNotifier(String type, Class<T> clazz, T object) throws CloudManagerFault, InvalidRole {
-			this.type = type;
-			this.clazz = clazz;
-			this.object = object;
-			try {
-				ObjectRegistryService.registry().get(IObjectChangedService.class).firePreAddedEvent(type, clazz, object);
-			}
-			catch (CloudManagerFault e) {
-				if (e.getCause() instanceof InvalidRole) throw (InvalidRole)e.getCause();
-				throw e;
-			}
-			catch (PluginFault e) {
-				throw new CloudManagerFault(e);
-			}
-		}
-		
-		@Override
-		public void close() throws CloudManagerFault, InvalidRole {
-			try {
-				ObjectRegistryService.registry().get(IObjectChangedService.class).firePostAddedEvent(type, clazz, object);
-			}
-			catch (CloudManagerFault e) {
-				if (e.getCause() instanceof InvalidRole) throw (InvalidRole)e.getCause();
-				throw e;
-			}
-			catch (PluginFault e) {
-				throw new CloudManagerFault(e);
-			}
-		}
-	}
-	
-	public static class ModifiedEventNotifier<T> implements AutoCloseable {
-		private String type;
-		private Class<T> clazz;
-		private T object;
-		
-		public ModifiedEventNotifier(String type, Class<T> clazz, T object) throws CloudManagerFault, InvalidRole {
-			this.type = type;
-			this.clazz = clazz;
-			this.object = object;
-			try {
-				ObjectRegistryService.registry().get(IObjectChangedService.class).firePreModifiedEvent(type, clazz, object);
-			}
-			catch (CloudManagerFault e) {
-				if (e.getCause() instanceof InvalidRole) throw (InvalidRole)e.getCause();
-				throw e;
-			}
-			catch (PluginFault e) {
-				throw new CloudManagerFault(e);
-			}
-		}
-		
-		@Override
-		public void close() throws CloudManagerFault, InvalidRole {
-			try {
-				ObjectRegistryService.registry().get(IObjectChangedService.class).firePostModifiedEvent(type, clazz, object);
-			}
-			catch (CloudManagerFault e) {
-				if (e.getCause() instanceof InvalidRole) throw (InvalidRole)e.getCause();
-				throw e;
-			}
-			catch (PluginFault e) {
-				throw new CloudManagerFault(e);
-			}
-		}
-	}
-	
 	private static class CriticalPoint {
 		private AtomicInteger syncCount = new AtomicInteger();
 
@@ -186,105 +112,6 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 		return cp;
 	}
 
-	private static class RegistAgent implements Runnable {
-		private String facilityId;
-		private int count = 0;
-		private int maxCount = Integer.parseInt(CloudPropertyConstants.agent_connection_count.value());
-		
-		public RegistAgent(String facilityId) {
-			this.facilityId = facilityId;
-		}
-
-		@Override
-		public void run() {
-			Logger logger = Logger.getLogger(this.getClass());
-			++count;
-			logger.debug("try to regist agent " + facilityId + " " + count + "/" + maxCount + " time.");
-
-			boolean success = false;
-			try {
-				// ノードが削除されていないか確認。
-				// sendManagerDiscoveryInfo は、FacilityNotFound　をスローしないので必要。
-				RepositoryControllerBeanWrapper.bean().getNode(facilityId);
-				success = AgentConnectUtil.sendManagerDiscoveryInfo(facilityId);
-			}
-			catch (FacilityNotFound e) {
-				logger.warn(e.getMessage(), e);
-				// 終了のために RuntimeException をスロー。
-				throw new RuntimeException();
-			}
-			catch (Exception e) {
-				logger.warn(e.getMessage(), e);
-			}
-
-			if (success) {
-				logger.info("success to regist " + facilityId + " as agent.");
-				// 終了のために RuntimeException をスロー。
-				throw new RuntimeException();
-			}
-			
-			if (maxCount <= count) {
-				logger.warn("timed out. agent doesn't exist.");
-				// 終了のために RuntimeException をスロー。
-				throw new RuntimeException();
-			}
-		}
-	}
-	
-	public static void asyncRegistAgent(String facilityId) {
-		Logger logger = Logger.getLogger(InstanceOperator.class);
-		logger.info("start to ping " + facilityId + " as agent for register.");
-		SessionService.scheduleWithFixedDelay(new RegistAgent(facilityId), 0, Long.parseLong(CloudPropertyConstants.agent_connection_interval.value()), TimeUnit.MILLISECONDS);
-	}
-
-	public static void registAgent(String facilityId) {
-		Logger logger = Logger.getLogger(InstanceOperator.class);
-		logger.info("start to ping " + facilityId + " as agent for register.");
-		
-		RegistAgent ra = new RegistAgent(facilityId);
-		try {
-			for (;;) {
-				ra.run();
-				Thread.sleep(Long.parseLong(CloudPropertyConstants.agent_connection_interval.value()));
-			}
-		}
-		catch (Exception e) {
-		}
-	}
-
-	public static Boolean findAgent(String facilityId) throws CloudManagerFault {
-		Logger logger = Logger.getLogger(TemplateJobUtil.class);
-
-		try {
-			logger.info("start to check " + facilityId + " as agent for register.");
-
-			boolean result = false;
-			int counter = 0;
-			int maxCount = Integer.parseInt(CloudPropertyConstants.agent_connection_count.value());
-			long interval = Long.parseLong(CloudPropertyConstants.agent_connection_interval.value());
-			while (counter < maxCount) {
-				counter++;
-				logger.debug("trｙ to find agent " + facilityId + " " + counter + "/" + maxCount + " time.");
-
-				// ノードが削除されていないか確認。
-				RepositoryControllerBeanWrapper.bean().getNode(facilityId);
-
-				if (AgentConnectUtil.isValidAgent(facilityId)) {
-					logger.info("success to find " + facilityId + " as agent.");
-					return true;
-				}
-
-				if (counter >= maxCount) {
-					throw new CloudManagerFault("timed out. agent doesn't exist.");
-				}
-				Thread.sleep(interval);
-			}
-			
-			return result;
-		} catch (Exception e) {
-			throw new CloudManagerFault(e);
-		}
-	}
 
 	public InstanceOperator() throws CloudManagerFault {
 	}
@@ -303,7 +130,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 				request.getImageId(), request.getZone(),
 				request.getInstanceDetail(), null, request.getTags());
 		if (instance.getFacilityId() != null) {
-			asyncRegistAgent(instance.getFacilityId());
+			RegistAgent.asyncRegistAgent(instance.getFacilityId());
 		}
 		return instance;
 	}
@@ -324,7 +151,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 					new JobEventListener() {
 						@Override
 						public void jobEventOccurerd(String facilityId, String jobunitId, String jobId) throws Exception {
-							InstanceOperator.registAgent(facilityId);
+							RegistAgent.registAgent(facilityId);
 						}
 					},
 					null);
@@ -333,8 +160,21 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 		return ci;
 	}
 
+	@SuppressWarnings("unchecked")
 	@Override
 	public CloudInstanceBackup createInstanceBackup(CreateInstanceBackupRequest request) throws CloudManagerFault, InvalidRole {
+		CreateInstanceBackupRequest2 request2 = new CreateInstanceBackupRequest2();
+		request2.setName(request.getName());
+		request2.setInstanceId(request.getInstanceId());
+		request2.setDescription(request.getDescription());
+		request2.setNoReboot(request.getNoReboot());
+		request2.setStorageIds(request.getWithVolumes() ? null: (List<String>)Collections.EMPTY_LIST);
+		request2.setDetail(request.getDetail());
+		return createInstanceBackup2(request2);
+	}
+	
+	@Override
+	public CloudInstanceBackup createInstanceBackup2(CreateInstanceBackupRequest2 request) throws CloudManagerFault, InvalidRole {
 		IResourceManagement rm = getResourceManagement();
 
 		CloudInstance instance = getInstance(request.getInstanceId());
@@ -349,9 +189,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 			throw ErrorCode.HINEMOS_MANAGER_ERROR.cloudManagerFault(e);
 		}
 
-		InstanceBackup instanceBackup = rm.createInstanceBackup(
-				request.getInstanceId(), request.getName(),
-				request.getDescription(), request.getWithVolumes(), request.getNoReboot(), request.getDetail());
+		InstanceBackup instanceBackup = rm.createInstanceBackup(request.getInstanceId(), request.getName(), request.getDescription(), request.getNoReboot(), request.getStorageIds(), request.getDetail());
 
 		CloudInstanceBackupDao dao = new CloudInstanceBackupDao();
 		dao.setInstanceBackupId(instanceBackup.getInstanceBackupId());
@@ -491,6 +329,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 			try (ModifiedEventNotifier<NodeInfo> notifier = new ModifiedEventNotifier<>(CloudConstants.Node_Instance_Modify, NodeInfo.class, nodeInfo)) {
 				try {
 					repositoryControllerBean.modifyNode(nodeInfo);
+					notifier.setCompleted();
 				}
 				catch (InvalidSetting | HinemosUnknown e) {
 					throw ErrorCode.HINEMOS_MANAGER_ERROR.cloudManagerFault(e);
@@ -526,6 +365,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 			try (AddedEventNotifier<NodeInfo> notifier = new AddedEventNotifier<>(CloudConstants.Node_Instance_Add, NodeInfo.class, nodeInfo)) {
 				try {
 					repositoryControllerBean.addNode(nodeInfo);
+					notifier.setCompleted();
 				}
 				catch (FacilityDuplicate e) {
 					throw ErrorCode.CLOUDINSTANCE_DUPLICATE_NODE.cloudManagerFault(dao.getAccountResourceId(), dao.getInstanceId(), nodeDetail.getFacilityId());
@@ -650,7 +490,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 						new JobEventListener() {
 							@Override
 							public void jobEventOccurerd(String facilityId, String jobunitId, String jobId) throws Exception {
-								findAgent(facilityId);
+								RegistAgent.findAgent(facilityId);
 							}
 						},
 						null);
@@ -760,131 +600,138 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 		return result;
 	}
 
-	protected UpdateResult internalUpdate(CloudInstanceDao cloudInstanceDao, Instance instance, boolean entering) throws CloudManagerFault, InvalidRole {
+	protected UpdateResult transactionalInternalUpdate(CloudInstanceDao cloudInstanceDao, Instance instance, boolean entering) throws CloudManagerFault, InvalidRole {
+		UpdateResult result = null;
 		try (TransactionScope scope = new TransactionScope(Transactional.TransactionType.RequiredNew)) {
-			try {
-				EntityManagerEx em = SessionService.current().getEntityManagerEx();
-				if (cloudInstanceDao != null) {
-					//　EntityManager が切り替わっているので、再度取得。
-					cloudInstanceDao = em.getReference(CloudInstanceDao.class, cloudInstanceDao.getId());
-				}
-				
-				if (instance != null) {
-					if (cloudInstanceDao == null) {
-						// 非同期で動作するインスタンス作成や別の更新処理が動作していない場合に、以下の処理を継続する。
-						if (update && !entering) {
-							// AWS インスタンスに対応するインスタンス情報を追加。
-							try {
-								cloudInstanceDao = createCloudInstanceDao(instance, null);
-							}
-							catch (CloudManagerFault e) {
-								// CloudInstanceDao 作成済みの場合に関しては、このインスタンスへの処理をキャンセルし、
-								// 処理を継続させる。
-								// 非同期で動作するインスタンス作成や別の更新処理が先に作成している場合があるので、
-								// エラーとはしない。
-								if (ErrorCode.CLOUDINSTANCE_ALREADY_EXIST.match(e)) {
-									// 別の処理が作成済みらしい。
-									cloudInstanceDao = em.find(CloudInstanceDao.class, new CloudInstanceDao.CloudInstancePK(instance.getInstanceId(), getCloudRegion().getRegion(), getCloudUser().getAccountResourceId()));
-									if (cloudInstanceDao == null) {
-										throw e;
-									}
-								}
-								else {
-									throw e;
-								}
-							}
-		
-							// AWS インスタンスに対するノードを自動で作成するかどうか？
-							if (regist) {
-								// ノードの自動作成。
-								addNodeRelation(cloudInstanceDao, instance);
-		
-								if (relation) {
-									relateExistedScope(cloudInstanceDao.getFacilityId(), instance);
-								}
-								else {
-									// 特になにもしない。
-								}
-		
-								if (cloudInstanceDao.getFacilityId() != null) {
-									asyncRegistAgent(cloudInstanceDao.getFacilityId());
-								}
-							} else {
-								// 特になにもしない。
-							}
-						}
-					} else {
-						if (update) {
-							// 登録済みの情報を更新。
-							updateCloudInstanceDao(cloudInstanceDao, instance);
-		
-							if (cloudInstanceDao.getFacilityId() == null) {
-								// AWS インスタンスに対するノードを自動で作成するかどうか？
-								if (regist) {
-									// ノードの自動作成。
-									addNodeRelation(cloudInstanceDao, instance);
-		
-									if (relation) {
-										relateExistedScope(cloudInstanceDao.getFacilityId(), instance);
-									} else {
-										// 特になにもしない。
-									}
-		
-									if (cloudInstanceDao.getFacilityId() != null) {
-										asyncRegistAgent(cloudInstanceDao.getFacilityId());
-									}
-								} else {
-									// 特になにもしない。
-								}
-							} else {
-								if (relation) {
-									relateExistedScope(cloudInstanceDao.getFacilityId(), instance);
-								} else {
-									// 特になにもしない。
-								}
-							}
-						}
-					}
-				}
-				else {
-					if (cloudInstanceDao != null) {
-						if (update) {
-							if (cloudInstanceDao.getRegistStatus() != CloudInstanceDao.InstanceStatus.deleted) {
-								cloudInstanceDao.setRegistStatus(CloudInstanceDao.InstanceStatus.deleted);
-							}
-		
-							// 該当するノード情報を自動で削除するかどうか。
-							if (regist) {
-								// AWS インスタンスがないので自動削除。
-								removeNodeRelation(cloudInstanceDao);
-							}
-						}
-		
-						// ノードと紐づいていないなら、削除。
-						if (cloudInstanceDao.getFacilityId() == null) {
-							deleteInstance(cloudInstanceDao);
-							cloudInstanceDao = null;
-						}
-					} else {
-						// どちらもないのでスルー
-					}
-				}
+			EntityManagerEx em = SessionService.current().getEntityManagerEx();
+			if (cloudInstanceDao != null) {
+				//　EntityManager が切り替わっているので、再度取得。
+				cloudInstanceDao = em.find(CloudInstanceDao.class, cloudInstanceDao.getId());
 			}
-			catch (CloudManagerFault e) {
-				if (ErrorCode.CLOUDINSTANCE_DUPLICATE_NODE.match(e) || ErrorCode.HINEMOS_MANAGER_ERROR.match(e)) {
-					CloudMessageUtil.notify_AutoUpadate_Error_InstanceOperator(cloudInstanceDao.getAccountResourceId(), cloudInstanceDao.getInstanceId(), e);
-				}
-				else {
-					throw e;
-				}
-			}
-
+			
+			result =  internalUpdate(cloudInstanceDao, instance, entering);
+			
 			scope.complete();
 		}
 		catch (CloudManagerFault e) {
 			CloudMessageUtil.notify_AutoUpadate_Error_InstanceOperator(cloudInstanceDao.getAccountResourceId(), cloudInstanceDao.getInstanceId(), e);
 		}
+		
+		return result;
+	}
 
+	protected UpdateResult internalUpdate(CloudInstanceDao cloudInstanceDao, Instance instance, boolean entering) throws CloudManagerFault, InvalidRole {
+		try {
+			if (instance != null) {
+				if (cloudInstanceDao == null) {
+					// 非同期で動作するインスタンス作成や別の更新処理が動作していない場合に、以下の処理を継続する。
+					if (update && !entering) {
+						// AWS インスタンスに対応するインスタンス情報を追加。
+						try {
+							cloudInstanceDao = createCloudInstanceDao(instance, null);
+						}
+						catch (CloudManagerFault e) {
+							// CloudInstanceDao 作成済みの場合に関しては、このインスタンスへの処理をキャンセルし、
+							// 処理を継続させる。
+							// 非同期で動作するインスタンス作成や別の更新処理が先に作成している場合があるので、
+							// エラーとはしない。
+							if (ErrorCode.CLOUDINSTANCE_ALREADY_EXIST.match(e)) {
+								// 別の処理が作成済みらしい。
+								EntityManagerEx em = SessionService.current().getEntityManagerEx();
+								cloudInstanceDao = em.find(CloudInstanceDao.class, new CloudInstanceDao.CloudInstancePK(instance.getInstanceId(), getCloudRegion().getRegion(), getCloudUser().getAccountResourceId()));
+								if (cloudInstanceDao == null) {
+									throw e;
+								}
+							}
+							else {
+								throw e;
+							}
+						}
+	
+						// AWS インスタンスに対するノードを自動で作成するかどうか？
+						if (regist) {
+							// ノードの自動作成。
+							addNodeRelation(cloudInstanceDao, instance);
+	
+							if (relation) {
+								relateExistedScope(cloudInstanceDao.getFacilityId(), instance);
+							}
+							else {
+								// 特になにもしない。
+							}
+	
+							if (cloudInstanceDao.getFacilityId() != null) {
+								RegistAgent.asyncRegistAgent(cloudInstanceDao.getFacilityId());
+							}
+						} else {
+							// 特になにもしない。
+						}
+					}
+				} else {
+					if (update) {
+						// 登録済みの情報を更新。
+						updateCloudInstanceDao(cloudInstanceDao, instance);
+	
+						if (cloudInstanceDao.getFacilityId() == null) {
+							// AWS インスタンスに対するノードを自動で作成するかどうか？
+							if (regist) {
+								// ノードの自動作成。
+								addNodeRelation(cloudInstanceDao, instance);
+	
+								if (relation) {
+									relateExistedScope(cloudInstanceDao.getFacilityId(), instance);
+								} else {
+									// 特になにもしない。
+								}
+	
+								if (cloudInstanceDao.getFacilityId() != null) {
+									RegistAgent.asyncRegistAgent(cloudInstanceDao.getFacilityId());
+								}
+							} else {
+								// 特になにもしない。
+							}
+						} else {
+							if (relation) {
+								relateExistedScope(cloudInstanceDao.getFacilityId(), instance);
+							} else {
+								// 特になにもしない。
+							}
+						}
+					}
+				}
+			}
+			else {
+				if (cloudInstanceDao != null) {
+					if (update) {
+						if (cloudInstanceDao.getRegistStatus() != CloudInstanceDao.InstanceStatus.deleted) {
+							cloudInstanceDao.setRegistStatus(CloudInstanceDao.InstanceStatus.deleted);
+						}
+	
+						// 該当するノード情報を自動で削除するかどうか。
+						if (regist) {
+							// AWS インスタンスがないので自動削除。
+							removeNodeRelation(cloudInstanceDao);
+						}
+					}
+	
+					// ノードと紐づいていないなら、削除。
+					if (cloudInstanceDao.getFacilityId() == null) {
+						deleteInstance(cloudInstanceDao);
+						cloudInstanceDao = null;
+					}
+				} else {
+					// どちらもないのでスルー
+				}
+			}
+		}
+		catch (CloudManagerFault e) {
+			if (ErrorCode.CLOUDINSTANCE_DUPLICATE_NODE.match(e) || ErrorCode.HINEMOS_MANAGER_ERROR.match(e)) {
+				CloudMessageUtil.notify_AutoUpadate_Error_InstanceOperator(cloudInstanceDao.getAccountResourceId(), cloudInstanceDao.getInstanceId(), e);
+			}
+			else {
+				throw e;
+			}
+		}
 		return new UpdateResult(instance, cloudInstanceDao);
 	}
 
@@ -1037,15 +884,16 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 						getCloudRegion().getRegion())).isEntering();
 
 		// AWS にも Hinemos DB にも登録されている。
-		for (UpdateAllResult.InstanceMapping storageMapping : instanceMappings) {
-			internalUpdate(storageMapping.cloudInstance, storageMapping.instance, entering);
+		for (UpdateAllResult.InstanceMapping instanceMapping : instanceMappings) {
+			UpdateResult result = transactionalInternalUpdate(instanceMapping.cloudInstance, instanceMapping.instance, entering);
+			instanceMapping.cloudInstance = result.cloudInstance;
 		}
 		both.addAll(instanceMappings);
 
 		// AWS のみに存在する。
 		// インスタンスの自動更新フラグが有効になっているなら、自動登録処理実施。
 		for (Instance i : awsInstances) {
-			UpdateResult updateResult = internalUpdate(null, i, entering);
+			UpdateResult updateResult = transactionalInternalUpdate(null, i, entering);
 
 			// ストレージの自動アタッチ。
 			if (updateResult.cloudInstance != null) {
@@ -1055,7 +903,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 		}
 
 		for (CloudInstanceDao cs : CloudInstanceDaos) {
-			UpdateResult updateResult = internalUpdate(cs, null, entering);
+			UpdateResult updateResult = transactionalInternalUpdate(cs, null, entering);
 
 			if (updateResult.cloudInstance != null) {
 				onlyCloud.add(updateResult.cloudInstance);
@@ -1111,6 +959,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 		try (AddedEventNotifier<NodeInfo> notifier = new AddedEventNotifier<>(CloudConstants.Node_Instance_Add, NodeInfo.class, nodeInfo)) {
 			try {
 				repositoryControllerBean.addNode(nodeInfo);
+				notifier.setCompleted();
 			}
 			catch (FacilityDuplicate e) {
 				throw ErrorCode.CLOUDINSTANCE_DUPLICATE_NODE.cloudManagerFault(dao.getAccountResourceId(), dao.getInstanceId(), nodeInfo.getFacilityId());
@@ -1231,6 +1080,7 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 				HinemosUtil.clearNodeInfo(nodeInfo);
 				try (ModifiedEventNotifier<NodeInfo> notifier = new ModifiedEventNotifier<>(CloudConstants.Node_Instance_Clear, NodeInfo.class, nodeInfo)) {
 					repositoryBean.modifyNode(nodeInfo);
+					notifier.setCompleted();
 				}
 			} catch (FacilityNotFound | HinemosUnknown | InvalidSetting e) {
 				throw ErrorCode.HINEMOS_MANAGER_ERROR.cloudManagerFault(e);
@@ -1401,7 +1251,45 @@ public class InstanceOperator extends ResourceOperatorBase implements IInstanceO
 
 	@Override
 	public List<CloudInstanceBackup> getInstanceBackupByInstanceId(String instanceId) throws CloudManagerFault {
-		return null;
+		EntityManagerEx em = SessionService.current().getEntityManagerEx();
+		Query query = em.createQuery("SELECT b FROM CloudInstanceBackupDao b WHERE b.backupedData.instanceId = :instanceId");
+		query.setParameter("instanceId", instanceId);
+
+		@SuppressWarnings("unchecked")
+		List<CloudInstanceBackupDao> daos = query.getResultList();
+		
+		List<CloudInstanceBackup> backups = new ArrayList<>();
+
+		List<String> backupIds = new ArrayList<>();
+		for (CloudInstanceBackupDao dao: daos) {
+			backupIds.add(dao.getInstanceBackupId());
+		}
+		List<InstanceBackup> cloudBackups = getResourceManagement().getInstanceBackups(backupIds);
+		
+		List<CloudInstanceBackupDao> tempBackupDaos = new ArrayList<>(daos);
+		List<InstanceBackup> tempBackups = new ArrayList<>(cloudBackups);
+		
+		Iterator<CloudInstanceBackupDao> i = tempBackupDaos.iterator();
+		while (i.hasNext()) {
+			CloudInstanceBackupDao dao = i.next();
+			Iterator<InstanceBackup> j = tempBackups.iterator();
+			while (j.hasNext()) {
+				InstanceBackup backup = j.next();
+				if (backup.getInstanceBackupId().equals(dao.getInstanceBackupId())) {
+					backups.add(new CloudInstanceBackup(dao, backup));
+					i.remove();
+					j.remove();
+					break;
+				}
+			}
+		}
+		
+		for (CloudInstanceBackupDao dao: tempBackupDaos) {
+			if (dao.getRestoreStatus() == CloudInstanceBackupDao.RestoreStatus.available) {
+				dao.setRestoreStatus(CloudInstanceBackupDao.RestoreStatus.unavailable);
+			}
+		}
+		return backups;
 	}
 
 	// @Override
