@@ -13,6 +13,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.cloud.factory;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -21,6 +22,7 @@ import java.util.Map;
 import java.util.Set;
 
 import javax.persistence.EntityExistsException;
+import javax.persistence.Query;
 
 import org.apache.log4j.Logger;
 
@@ -207,102 +209,107 @@ public class StorageOperator extends ResourceOperatorBase implements IStorageOpe
 		return result;
 	}
 	
-	private UpdateResult internalUpdate(String region, CloudStorageDao cloudStorageDao, Storage storage) throws CloudManagerFault, InvalidRole {
+	private UpdateResult transactionalInternalUpdate(String region, CloudStorageDao cloudStorageDao, Storage storage) throws CloudManagerFault, InvalidRole {
+		UpdateResult result = null;
 		try (TransactionScope scope = new TransactionScope(Transactional.TransactionType.RequiredNew)) {
-			try {
-				EntityManagerEx em = SessionService.current().getEntityManagerEx();
-				if (cloudStorageDao != null) {
-					//　EntityManager が切り替わっているので、再度取得。
-					cloudStorageDao = em.getReference(CloudStorageDao.class, cloudStorageDao.getId());
-				}
-
-				if (storage != null) {
-					if (cloudStorageDao == null) {
-						if (update) {
-							try {
-								// AWS ボリュームが追加。
-								cloudStorageDao = createCloudStorageDao(storage);
-							}
-							catch (CloudManagerFault e) {
-								// 別の処理が作成済みらしい。
-								if (ErrorCode.CLOUDSTORAGE_ALREADY_EXIST.match(e)) {
-									cloudStorageDao = em.find(CloudStorageDao.class, new CloudStorageDao.CloudStoragePK(storage.getStorageId(), region, getCloudUser().getAccountResourceId()));
-									if (cloudStorageDao == null) {
-										throw e;
-									}
-									return new UpdateResult(getCloudService().getCloudTypeId(), storage, cloudStorageDao);
+			EntityManagerEx em = SessionService.current().getEntityManagerEx();
+			if (cloudStorageDao != null) {
+				//　EntityManager が切り替わっているので、再度取得。
+				cloudStorageDao = em.find(CloudStorageDao.class, cloudStorageDao.getId());
+			}
+			result = internalUpdate(region, cloudStorageDao, storage);
+			scope.complete();
+		}
+		return result;
+	}
+	
+	private UpdateResult internalUpdate(String region, CloudStorageDao cloudStorageDao, Storage storage) throws CloudManagerFault, InvalidRole {
+		try {
+			if (storage != null) {
+				if (cloudStorageDao == null) {
+					if (update) {
+						try {
+							// AWS ボリュームが追加。
+							cloudStorageDao = createCloudStorageDao(storage);
+						}
+						catch (CloudManagerFault e) {
+							// 別の処理が作成済みらしい。
+							if (ErrorCode.CLOUDSTORAGE_ALREADY_EXIST.match(e)) {
+								EntityManagerEx em = SessionService.current().getEntityManagerEx();
+								cloudStorageDao = em.find(CloudStorageDao.class, new CloudStorageDao.CloudStoragePK(storage.getStorageId(), region, getCloudUser().getAccountResourceId()));
+								if (cloudStorageDao == null) {
+									throw e;
 								}
-								throw e;
-							}
-		
-							// インスタンスに対するノードのようなストレージに対するオブジェクトが存在しないので、以下のフラグは無視。
-							if (regist) {
-							}
-							else {
-							}
-		
-							if (mount) {
-								addStorageRelation(region, cloudStorageDao, storage);
-							}
-							else {
-								// マウントに関わる情報は無視。
+								return new UpdateResult(getCloudService().getCloudTypeId(), storage, cloudStorageDao);
 							}
+							throw e;
 						}
-						else {
-						}
-					}
-					else {
-						if (update) {
-							// 登録済みの情報を更新。
-							updateCloudStorageDao(cloudStorageDao, storage);
-						}
-						else {
-						}
-						
-						if (mount) {
-							updateStorageRelation(region, cloudStorageDao, storage);
-						}
-						else {
-							// マウントに関わる情報は無視。
-						}
-					}
-				}
-				else {
-					if (cloudStorageDao != null) {
-						if (update) {
-							if (cloudStorageDao.getRegistStatus() != CloudStorageDao.StorageStatus.deleted) {
-								cloudStorageDao.setRegistStatus(CloudStorageDao.StorageStatus.deleted);
-							}
-						}
-						
-						if (mount) {
-							removeStorageRelation(cloudStorageDao);
-						}
-						else {
-						}
-						
+	
 						// インスタンスに対するノードのようなストレージに対するオブジェクトが存在しないので、以下のフラグは無視。
 						if (regist) {
 						}
 						else {
 						}
-		
-						// ディスク情報が無い場合は、削除。
-						if (cloudStorageDao.getFacilityId() == null) {
-							deleteStorage(cloudStorageDao);
-							cloudStorageDao = null;
+	
+						if (mount) {
+							addStorageRelation(region, cloudStorageDao, storage);
+						}
+						else {
+							// マウントに関わる情報は無視。
 						}
 					}
 					else {
-						// どちらもないのでスルー
+					}
+				}
+				else {
+					if (update) {
+						// 登録済みの情報を更新。
+						updateCloudStorageDao(cloudStorageDao, storage);
+					}
+					else {
+					}
+					
+					if (mount) {
+						updateStorageRelation(region, cloudStorageDao, storage);
+					}
+					else {
+						// マウントに関わる情報は無視。
 					}
 				}
 			}
-			catch (CloudManagerFault e) {
-				CloudMessageUtil.notify_AutoUpadate_Error_StorageOperator(cloudStorageDao.getAccountResourceId(), cloudStorageDao.getStorageId(), e);
+			else {
+				if (cloudStorageDao != null) {
+					if (update) {
+						if (cloudStorageDao.getRegistStatus() != CloudStorageDao.StorageStatus.deleted) {
+							cloudStorageDao.setRegistStatus(CloudStorageDao.StorageStatus.deleted);
+						}
+					}
+					
+					if (mount) {
+						removeStorageRelation(cloudStorageDao);
+					}
+					else {
+					}
+					
+					// インスタンスに対するノードのようなストレージに対するオブジェクトが存在しないので、以下のフラグは無視。
+					if (regist) {
+					}
+					else {
+					}
+	
+					// ディスク情報が無い場合は、削除。
+					if (cloudStorageDao.getFacilityId() == null) {
+						deleteStorage(cloudStorageDao);
+						cloudStorageDao = null;
+					}
+				}
+				else {
+					// どちらもないのでスルー
+				}
 			}
-
-			scope.complete();
+		}
+		catch (CloudManagerFault e) {
+			CloudMessageUtil.notify_AutoUpadate_Error_StorageOperator(cloudStorageDao.getAccountResourceId(), cloudStorageDao.getStorageId(), e);
 		}
 		return new UpdateResult(getCloudService().getCloudTypeId(), storage, cloudStorageDao);
 	}
@@ -400,14 +407,15 @@ public class StorageOperator extends ResourceOperatorBase implements IStorageOpe
 
 		// AWS にも Hinemos DB にも登録されている。
 		for (StorageMapping storageMapping: storageMappings) {
-			internalUpdate(getCloudRegion().getRegion(), storageMapping.cloudStorage, storageMapping.storage);
+			UpdateResult updateResult = transactionalInternalUpdate(getCloudRegion().getRegion(), storageMapping.cloudStorage, storageMapping.storage);
+			storageMapping.cloudStorage = updateResult.cloudStorage;
 		}
 		both.addAll(storageMappings);
 
 		// AWS のみに存在する。 
 		// インスタンスの自動更新フラグが有効になっているなら、自動登録処理実施。
 		for (Storage s: sList) {
-			UpdateResult updateResult = internalUpdate(getCloudRegion().getRegion(), null, s);
+			UpdateResult updateResult = transactionalInternalUpdate(getCloudRegion().getRegion(), null, s);
 			if (updateResult.cloudStorage != null) {
 				// ストレージの自動アタッチ。
 				onlyAws.add(new StorageMapping(updateResult.stroage, updateResult.cloudStorage));
@@ -416,7 +424,7 @@ public class StorageOperator extends ResourceOperatorBase implements IStorageOpe
 		}
 		
 		for (CloudStorageDao cs: csList) {
-			UpdateResult updateResult = internalUpdate(getCloudRegion().getRegion(), cs, null);
+			UpdateResult updateResult = transactionalInternalUpdate(getCloudRegion().getRegion(), cs, null);
 			if (updateResult.cloudStorage != null) {
 				onlyCloud.add(updateResult.cloudStorage);
 			}
@@ -687,8 +695,44 @@ public class StorageOperator extends ResourceOperatorBase implements IStorageOpe
 
 	@Override
 	public List<CloudStorageBackup> getStorageBuckupsByStorageId(String storageId) throws CloudManagerFault {
-		// TODO Auto-generated method stub
-		return null;
+		EntityManagerEx em = SessionService.current().getEntityManagerEx();
+		Query query = em.createQuery("SELECT b FROM CloudStorageBackupDao b WHERE b.backupedData.storageId = :storageId");
+		query.setParameter("storageId", storageId);
+		@SuppressWarnings("unchecked")
+		List<CloudStorageBackupDao> daos = query.getResultList();
+		if (daos.isEmpty()) return Collections.emptyList();
+		
+		List<CloudStorageBackup> backups = new ArrayList<>();
+		List<String> backupIds = new ArrayList<>();
+		for (CloudStorageBackupDao dao: daos) {
+			backupIds.add(dao.getStorageBackupId());
+		}
+		List<StorageBackup> cloudBackups = getResourceManagement().getStorageBackups(backupIds);
+		
+		List<CloudStorageBackupDao> tempBackupDaos = new ArrayList<>(daos);
+		List<StorageBackup> tempBackups = new ArrayList<>(cloudBackups);
+		
+		Iterator<CloudStorageBackupDao> i = tempBackupDaos.iterator();
+		while (i.hasNext()) {
+			CloudStorageBackupDao dao = i.next();
+			Iterator<StorageBackup> j = tempBackups.iterator();
+			while (j.hasNext()) {
+				StorageBackup backup = j.next();
+				if (backup.getStorageBackupId().equals(dao.getStorageBackupId())) {
+					backups.add(new CloudStorageBackup(dao, backup));
+					i.remove();
+					j.remove();
+					break;
+				}
+			}
+		}
+		
+		for (CloudStorageBackupDao dao: tempBackupDaos) {
+			if (dao.getRestoreStatus() == CloudStorageBackupDao.RestoreStatus.available) {
+				dao.setRestoreStatus(CloudStorageBackupDao.RestoreStatus.unavailable);
+			}
+		}
+		return backups;
 	}
 
 //	@Override
