@@ -1,3 +1,15 @@
+/*
+Copyright (C) 2013 NTT DATA Corporation
+
+This program is free software; you can redistribute it and/or
+Modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation, version 2.
+
+This program is distributed in the hope that it will be
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+PURPOSE.  See the GNU General Public License for more details.
+ */
 package com.clustercontrol.cloud.util;
 
 import java.util.ArrayList;
@@ -12,6 +24,7 @@ import com.clustercontrol.cloud.IMessagesHolder;
 import com.clustercontrol.cloud.InternalManagerError;
 import com.clustercontrol.cloud.bean.CloudRegion;
 import com.clustercontrol.cloud.commons.CloudConstants;
+import com.clustercontrol.cloud.factory.AddedEventNotifier;
 import com.clustercontrol.cloud.factory.ICloudServiceOperator;
 import com.clustercontrol.cloud.registry.IObjectChangedService;
 import com.clustercontrol.cloud.registry.ObjectRegistryService;
@@ -95,28 +108,42 @@ public class AccountResourceUtil {
 		}
 	}
 	
+	private static void createCloudScopeIfNotExist(RepositoryControllerBean repositoryBean, IMessagesHolder messages) throws HinemosUnknown, InvalidRole, FacilityDuplicate, InvalidSetting, CloudManagerFault {
+		try {
+			repositoryBean.getScope(cloudRootScopeId);
+		}
+		catch (FacilityNotFound e1) {
+			ScopeInfo scopeInfo = HinemosUtil.createScope(cloudRootScopeId, messages.getString(cloudRootScopeNameId), RoleIdConstant.ADMINISTRATORS);
+			try (AddedEventNotifier<ScopeInfo> notifier = new AddedEventNotifier<>(CloudConstants.Node_Cloud_Add, ScopeInfo.class, scopeInfo)) {
+				repositoryBean.addScope(null, scopeInfo);
+				notifier.setCompleted();
+			}
+		}
+	}
+	
+	private static void createAccountResourceScopeIfNotExist(RepositoryControllerBean repositoryBean, AccountResourceIdHelper idHelper, String accountResourceName, String roleId) throws HinemosUnknown, InvalidRole, FacilityDuplicate, InvalidSetting, CloudManagerFault {
+		try {
+			repositoryBean.getScope(idHelper.getScopeId());
+		}
+		catch (FacilityNotFound e1) {
+			ScopeInfo scopeInfo = HinemosUtil.createScope(idHelper.getScopeId(), accountResourceName, roleId);
+			try (AddedEventNotifier<ScopeInfo> notifier = new AddedEventNotifier<>(CloudConstants.Node_CloudAccountResourceScope_Add, ScopeInfo.class, scopeInfo)) {
+				repositoryBean.addScope(cloudRootScopeId, scopeInfo);
+				notifier.setCompleted();
+			}
+		}
+	}
+
 	// スコープへ関連付け。
-	public static void attachScope(RepositoryControllerBean repositoryBean, String accountResourceId, String accountResourceName, String region, String regionName, String zone, String facilityId, String roleId, IMessagesHolder messages) throws InvalidSetting, InvalidRole, HinemosUnknown, FacilityDuplicate {
+	public static void attachScope(RepositoryControllerBean repositoryBean, String accountResourceId, String accountResourceName, String region, String regionName, String zone, String facilityId, String roleId, IMessagesHolder messages) throws InvalidSetting, InvalidRole, HinemosUnknown, FacilityDuplicate, CloudManagerFault {
 		AccountResourceIdHelper idHelper = new AccountResourceIdHelper(accountResourceId);
 		try {
 			repositoryBean.assignNodeScope(idHelper.decorateZone(zone), new String[]{facilityId});
 		}
 		catch(InvalidSetting e) {
-			try {
-				repositoryBean.getScope(cloudRootScopeId);
-			}
-			catch (FacilityNotFound e1) {
-				ScopeInfo scopeInfo = HinemosUtil.createScope(cloudRootScopeId, messages.getString(cloudRootScopeNameId), RoleIdConstant.ADMINISTRATORS);
-				repositoryBean.addScope(null, scopeInfo);
-			}
-
-			try {
-				repositoryBean.getScope(idHelper.getScopeId());
-			}
-			catch (FacilityNotFound e1) {
-				ScopeInfo scopeInfo = HinemosUtil.createScope(idHelper.getScopeId(), accountResourceName, roleId);
-				repositoryBean.addScope(cloudRootScopeId, scopeInfo);
-			}
+			createCloudScopeIfNotExist(repositoryBean, messages);
+			
+			createAccountResourceScopeIfNotExist(repositoryBean, idHelper, accountResourceName, roleId);
 
 			try {
 				repositoryBean.getScope(idHelper.decorateRegion(region));
@@ -331,20 +358,14 @@ public class AccountResourceUtil {
 			RepositoryControllerBean repositoryBean,
 			AccountResourceUtil.AccountResourceIdHelper idUtil,
 			NodeInfo nodeInfo,
-			IMessagesHolder messages) throws InvalidSetting, InvalidRole, HinemosUnknown, FacilityDuplicate {
+			IMessagesHolder messages) throws InvalidSetting, InvalidRole, HinemosUnknown, FacilityDuplicate, CloudManagerFault {
 		repositoryBean.addNode(nodeInfo);
 		
 		try {
 			repositoryBean.assignNodeScope(idUtil.getGroupId(), new String[]{nodeInfo.getFacilityId()});
 		}
 		catch(InvalidSetting e) {
-			try {
-				repositoryBean.getScope(cloudRootScopeId);
-			}
-			catch (FacilityNotFound e1) {
-				ScopeInfo scopeInfo = HinemosUtil.createScope(cloudRootScopeId, messages.getString(cloudRootScopeNameId), RoleIdConstant.ADMINISTRATORS);
-				repositoryBean.addScope(null, scopeInfo);
-			}
+			createCloudScopeIfNotExist(repositoryBean, messages);
 
 			try {
 				repositoryBean.getScope(cloudAccountResourceListId);
@@ -367,21 +388,9 @@ public class AccountResourceUtil {
 	}
 	
 	public static void registAccountResourceHierarchy(RepositoryControllerBean repositoryBean, AccountResourceUtil.AccountResourceIdHelper idUtil, String accountResourceName, String serviceId, String roleId, IMessagesHolder messages) throws FacilityDuplicate, InvalidSetting, InvalidRole, HinemosUnknown, FacilityDuplicate, CloudManagerFault {
-		try {
-			repositoryBean.getScope(cloudRootScopeId);
-		}
-		catch (FacilityNotFound e1) {
-			ScopeInfo scopeInfo = HinemosUtil.createScope(cloudRootScopeId, messages.getString(cloudRootScopeNameId), RoleIdConstant.ADMINISTRATORS);
-			repositoryBean.addScope(null, scopeInfo);
-		}
-
-		try {
-			repositoryBean.getScope(idUtil.getScopeId());
-		}
-		catch (FacilityNotFound e1) {
-			ScopeInfo scopeInfo = HinemosUtil.createScope(idUtil.getScopeId(), accountResourceName, roleId);
-			repositoryBean.addScope(cloudRootScopeId, scopeInfo);
-		}
+		createCloudScopeIfNotExist(repositoryBean, messages);
+		
+		createAccountResourceScopeIfNotExist(repositoryBean, idUtil, accountResourceName, roleId);
 
 		ICloudServiceOperator operator = ObjectRegistryService.registry().get(ICloudServiceOperator.class);
 		for (CloudRegion r: operator.findCloudRegionsByService(serviceId)) {
@@ -426,17 +435,17 @@ public class AccountResourceUtil {
 	// スコープへ関連付け。
 	public static void addAccountResourceRightToRole(AccessControllerBean accessBean, String roleId, String accountResourceId) throws PrivilegeDuplicate, UsedObjectPrivilege, HinemosUnknown, InvalidSetting, InvalidRole, JobMasterNotFound {
 		AccountResourceIdHelper idHelper = new AccountResourceIdHelper(accountResourceId);
-		HinemosUtil.addFullRightToRole(accessBean, roleId, HinemosModuleConstant.PLATFORM_REPOSITORY, idHelper.getScopeId());
-		HinemosUtil.addFullRightToRole(accessBean, roleId, HinemosModuleConstant.PLATFORM_REPOSITORY, idHelper.getGroupId());
-		HinemosUtil.addFullRightToRole(accessBean, roleId, HinemosModuleConstant.JOB, idHelper.getJobUnitId());
+		HinemosUtil.addFullRightToObject(accessBean, roleId, HinemosModuleConstant.PLATFORM_REPOSITORY, idHelper.getScopeId());
+		HinemosUtil.addFullRightToObject(accessBean, roleId, HinemosModuleConstant.PLATFORM_REPOSITORY, idHelper.getGroupId());
+		HinemosUtil.addFullRightToObject(accessBean, roleId, HinemosModuleConstant.JOB, idHelper.getJobUnitId());
 	}
 
 	// スコープへ関連付け。
 	public static void removeAccountResourceRightToRole(AccessControllerBean accessBean, String roleId, String accountResourceId) throws PrivilegeDuplicate, UsedObjectPrivilege, HinemosUnknown, InvalidSetting, InvalidRole, JobMasterNotFound {
 		AccountResourceIdHelper idHelper = new AccountResourceIdHelper(accountResourceId);
-		HinemosUtil.removeFullRightToRole(accessBean, roleId, HinemosModuleConstant.PLATFORM_REPOSITORY, idHelper.getScopeId());
-		HinemosUtil.removeFullRightToRole(accessBean, roleId, HinemosModuleConstant.PLATFORM_REPOSITORY, idHelper.getGroupId());
-		HinemosUtil.removeFullRightToRole(accessBean, roleId, HinemosModuleConstant.JOB, idHelper.getJobUnitId());
+		HinemosUtil.removeFullRightFromObject(accessBean, roleId, HinemosModuleConstant.PLATFORM_REPOSITORY, idHelper.getScopeId());
+		HinemosUtil.removeFullRightFromObject(accessBean, roleId, HinemosModuleConstant.PLATFORM_REPOSITORY, idHelper.getGroupId());
+		HinemosUtil.removeFullRightFromObject(accessBean, roleId, HinemosModuleConstant.JOB, idHelper.getJobUnitId());
 	}
 	
 	public static String createAccountResourceGroupId(String accountResourceId) {
