@@ -53,7 +53,6 @@ import com.clustercontrol.cloud.bean.Snapshot;
 import com.clustercontrol.cloud.bean.StartInstanceRequest;
 import com.clustercontrol.cloud.bean.StopInstanceRequest;
 import com.clustercontrol.cloud.bean.Zone;
-import com.clustercontrol.cloud.validation.ValidationFault;
 import com.clustercontrol.cloud.validation.annotation.Into;
 import com.clustercontrol.cloud.validation.annotation.NotNull;
 import com.clustercontrol.fault.InvalidRole;
@@ -67,55 +66,57 @@ import com.clustercontrol.fault.InvalidUserPass;
 @WebService(targetNamespace = "http://cloud.ws.clustercontrol.com")
 public interface CloudEndpoint {
 	/**
-	 * クラウドインスタンスの作成を AWS に指示し、該当するノードを作成します。
+	 * クラウドインスタンスの作成を対象のクラウドプラットフォームへ指示し、関連するノードも合わせて作成します。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param request クラウドインスタンス作成情報。
-	 * @return クラウド管理オプションに登録されたクライドインスタンスの詳細。
+	 * @return クラウド管理へ登録されたクライドインスタンスの詳細。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudInstance addInstance(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") CreateInstanceRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * テンプレートに従ったクラウドインスタンスの作成を AWS に指示し、該当するノードを作成します。
-	 * なお、エージェントが自動起動するよう設定された AMI イメージを用いてインスタンスを作成した場合、テンプレートに指定されたジョブを実行します。
+	 * テンプレートに従ったクラウドインスタンスの作成を対象のクラウドプラットフォームへ指示し、関連するノードも合わせて作成します。
+	 * なお、インスタンスを作成時に、エージェントが自動起動するように設定された イメージを指定すると、起動後テンプレートジョブが実行できます。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param request テンプレート付きのクラウドインスタンス作成情報。
 	 * @return クラウド管理オプションに登録されたクライドインスタンスの詳細。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudInstance addInstanceByTemplate(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") CreateInstanceByTemplateRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
 	 * 作成済みのクラウドインスタンスバックアップ情報から、クラウドインスタンスを復元します。
-	 * クラウドインスタンスバックアップ情報は、{@link #addInstanceBackup(CreateInstanceBackupRequest request) addInstanceBackup} にて作成します。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param request クラウドインスタンスバックアップ情報。
 	 * @return クラウド管理オプションに登録されたクライドインスタンスの詳細。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudInstance restoreInstance(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") RestoreInstanceRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * AWS からインスタンスを削除し、ノードが紐づいている場合は、併せて削除されます。
+	 * 対象のクラウド からインスタンスを削除し、ノードが紐づいている場合は、併せて削除されます。
 	 * 
-	 * @param region 削除するクラウドインスタンスが所属するリージョン名。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param instanceId 削除するクラウドインスタンス Id。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	void removeInstance(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "instanceId") String instanceId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -123,27 +124,27 @@ public interface CloudEndpoint {
 	/**
 	 * 作成済みのクラウドインスタンス情報を取得します。
 	 * 
-	 * @param regionName クラウドインスタンス情報が所属するリージョン名。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param instanceId クラウドインスタンス Id。
 	 * @return クラウドインスタンス情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudInstance getInstance(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "instanceId") String instanceId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
 	 * 指定したリージョンに作成されているインスタンス情報のリストを取得します。
-	 * 取得できるリストは、実行ユーザに紐づくクラウドユーザ(AWS アカウント、IMA ユーザ)の参照可能なインスタンスに限ります。
+	 * 取得できるリストは、実行ユーザに紐づくクラウドユーザの参照可能なインスタンスに限ります。
 	 * 
-	 * @param regionName リージョン名。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @return クラウドインスタンス情報の一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	List<CloudInstance> getInstancesByRegion(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -151,80 +152,79 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したクラウドインスタンスを起動します。
 	 * エージェントが自動起動可能なノードは、<br>
-	 * クラウドインスタンス作成時に{@link #addInstanceByTemplate(CreateInstanceByTemplateRequest request) テンプレートを指定した場合、｝
+	 * クラウドインスタンス作成時にテンプレートを指定した場合、
 	 * クラウドインスタンス起動後に、テンプレートに既定にて指定されているテンプレートジョブが実施されます。
 	 * また、テンプレートに指定されている既定のテンプレートジョブを切り替えたり、テンプレートが指定されていないエージェントでもテンプレートジョブを指定して起動することもできます。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param request クラウドインスタンス起動情報。
 	 * @return 起動後のクラウドインスタンスの状態情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	InstanceStateChange startInstance(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") StartInstanceRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
 	 * 指定したクラウドインスタンスを停止します。
-	 * クラウドインスタンス作成時に{@link #addInstanceByTemplate(CreateInstanceByTemplateRequest request) テンプレートを指定した場合、｝
+	 * クラウドインスタンス作成時にテンプレートを指定した場合、
 	 * クラウドインスタンス停止前に、テンプレートに既定にて指定されているテンプレートジョブが実施されます。
 	 * また、テンプレートに指定されている既定のテンプレートジョブを切り替えたり、テンプレートが指定されていないエージェントでもテンプレートジョブを指定して停止することもできます。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param request クラウドインスタンス停止情報。
 	 * @return 停止後のクラウドインスタンスの状態情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	InstanceStateChange stopInstance(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") StopInstanceRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * クラウドユーザ(AWS アカウント、IMA ユーザ)を追加します。
+	 * クラウドユーザを追加します。
 	 * クラウドユーザと Hinemos ユーザは一対一の関係となり、クラウドユーザに紐づいていない Hinemos ユーザが存在しない場合は、例外が発生します。
 	 * なお、クラウドユーザと紐づいた Hinemos ユーザーは、クラウドユーザを削除しないと削除することができません。
 	 * 
-	 * @param cloudUser クラウドユーザー情報。
+	 * @param request クラウドユーザー情報。
 	 * @return 作成したクラウドユーザーの詳細。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudUser addCloudUser(@NotNull @Into @WebParam(name = "request") CreateCloudUserRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * 指定したクラウドユーザ(AWS アカウント、IMA ユーザ)を取得します。
+	 * 指定したクラウドユーザを取得します。
 	 * 
 	 * @param userId ユーザーId。
 	 * @return クラウドユーザー情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudUser getCloudUser(@WebParam(name = "userId") String userId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * 指定したクラウドユーザ(AWS アカウント、IMA ユーザ)を削除します。
-	 * 削除対象のクラウドユーザが課金アラートを作成している場合は、クラウドユーザを削除するには、作成された課金アラートの削除が必要になります。
+	 * 指定したクラウドユーザを削除します。
 	 * 
 	 * @param userId ユーザーId。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	void removeCloudUser(@WebParam(name = "userId") String userId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * 全てのクラウドユーザ(AWS アカウント、IMA ユーザ)を取得します。
+	 * 指定したアカウントリソースに所属する全てのクラウドユーザを取得します。
 	 * 
+	 * @param アカウントリソース ID。
 	 * @return クラウドユーザー情報一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
@@ -234,22 +234,20 @@ public interface CloudEndpoint {
 	List<CloudUser> getCloudUsersByAccountResource(@WebParam(name = "accountResourceId") String accountResourceId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * 指定したクラウドユーザ(AWS アカウント、IMA ユーザ)の設定を変更します。
+	 * 指定したクラウドユーザの設定を変更します。
 	 * クラウドユーザID 以外は、null 指定が可能となり、値が指定された項目のみ更新されます。
 	 * 
-	 * @param cloudUser クラウドユーザー情報。
+	 * @param request クラウドユーザー情報。
 	 * @return クラウドユーザー情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudUser modifyCloudUser(@WebParam(name = "request") ModifyCloudUserRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
 	 * クラウドタイプを取得します。
-	 * 現在は、AWS のみ返します。
 	 * 
 	 * @return クラウドタイプ種別。
 	 * @throws CloudManagerFault
@@ -262,6 +260,7 @@ public interface CloudEndpoint {
 	/**
 	 * AWS の全てのリージョンを返します。
 	 * 
+	 * @param cloudServiceId　クラウドサービス ID。
 	 * @return リージョン情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
@@ -273,51 +272,34 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したリージョンに所属するアベイラビリティゾーンを返します。
 	 * 
-	 * @param regionName リージョン名。
-	 * @return アベイラビリティゾーン
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @return ゾーン一覧
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	List<Zone> getZones(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
 	 * 指定したリージョンおよびフィルター条件に該当する AMI イメージを返します。
-	 * フィルターの設定方法は、以下のリンクを参考にしてください。
-	 * <a http://docs.aws.amazon.com/AWSEC2/latest/APIReference/ApiReference-query-DescribeImages.html /> 
 	 * 
-	 * @param regionName リージョン名。
-	 * @param filter フィルター情報。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param filters フィルター情報。
 	 * @return AMI イメージ。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	List<Image> getImagesWithFilter(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "filters") List<Filter> filters) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
-//	/**
-//	 * 指定したリージョンおよびフィルター条件に該当する AMI イメージを返します。
-//	 * フィルターの設定方法は、以下のリンクを参考にしてください。
-//	 * <a http://docs.aws.amazon.com/AWSEC2/latest/APIReference/ApiReference-query-DescribeImages.html /> 
-//	 * 
-//	 * @param regionName リージョン名。
-//	 * @param filter フィルター情報。
-//	 * @return AMI イメージ。
-//	 * @throws CloudManagerFault
-//	 * @throws InvalidUserPass
-//	 * @throws InvalidRole
-//	 * @throws ValidationFault
-//	 */
-//	@WebMethod
-//	List<Snapshot> getAllImagesByRegion(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region) throws CloudManagerFault, InvalidUserPass, InvalidRole;
-
 	/**
 	 * 選択可能なインスタンス種別の一覧を取得します。
 	 * 
+	 * @param serviceId　クラウドサービス ID。
 	 * @return インスタンス種別。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
@@ -329,64 +311,43 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したリージョンおよびフィルターに該当するスナップショットの一覧を取得します。
 	 * フィルターの設定方法は、以下のリンクを参考にしてください。
-	 * <a http://docs.aws.amazon.com/AWSEC2/latest/APIReference/ApiReference-query-DescribeSnapshots.html /> 
 	 * 
-	 * @param regionName リージョン名。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param filter フィルター一覧。
-	 * @return スナップショット。
+	 * @return スナップショット一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	List<Snapshot> getSnapshotsWithFilter(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "filter") List<Filter> filter) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
-//	/**
-//	 * 指定したリージョンおよびフィルターに該当するスナップショットの一覧を取得します。
-//	 * フィルターの設定方法は、以下のリンクを参考にしてください。
-//	 * <a http://docs.aws.amazon.com/AWSEC2/latest/APIReference/ApiReference-query-DescribeSnapshots.html /> 
-//	 * 
-//	 * @param regionName リージョン名。
-//	 * @param filter フィルター一覧。
-//	 * @return スナップショット。
-//	 * @throws CloudManagerFault
-//	 * @throws InvalidUserPass
-//	 * @throws InvalidRole
-//	 * @throws ValidationFault
-//	 */
-//	@WebMethod
-//	List<Snapshot> getAllSnapshotsByRegion(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region) throws CloudManagerFault, InvalidUserPass, InvalidRole;
-
 	/**
 	 * 指定したインスタンスおよびストレージをアタッチします。
-	 * アタッチが完了すると　EC2 インスタンスへ EBS ボリュームがアタッチされ、該当するノードへは、<br>
-	 * EBS ボリュームの情報が反映されたディスク情報を追加されます。 
 	 * 
-	 * @param regionName リージョン名。
-	 * @param instanceId インスタンス Id。
-	 * @param storageId ストレージ Id。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param instanceId インスタンス ID。
+	 * @param storageId ストレージ ID。
 	 * @param device デバイス名。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	void attachStorage(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "instanceId") String instanceId, @WebParam(name = "storageId") String storageId, @WebParam(name = "device") String device) throws CloudManagerFault, InvalidUserPass, InvalidRole ;
 
 	/**
 	 * 指定したインスタンスからストレージをデタッチします。
-	 * アタッチが完了すると　EC2 インスタンスへ EBS ボリュームがアタッチされ、該当するノードへは、<br>
-	 * EBS ボリュームの情報が反映されたディスク情報を追加されます。 
 	 * 
-	 * @param regionName リージョン名。
-	 * @param instanceId インスタンス Id。
-	 * @param storageId ストレージ Id。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param instanceId インスタンス ID。
+	 * @param storageId ストレージ ID。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	void detachStorage(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "instanceId") String instanceId, @WebParam(name = "storageId") String storageId) throws CloudManagerFault, InvalidUserPass, InvalidRole ;
@@ -394,26 +355,27 @@ public interface CloudEndpoint {
 	/**
 	 * ストレージを追加します。
 	 * 
-	 * @param request 
-	 * @return
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param request ストレージ作成情報
+	 * @return ストレージ情報
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudStorage addStorage(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") CreateStorageRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole ;
 
 	/**
 	 * 作成済みのストレージバックアップ情報から、ストレージを復元します。
-	 * ストレージバックアップ情報は、{@link #addStorageBackup(CreateStorageBackupRequest request) addStorageBackup} にて作成します。
 	 * 
-	 * @param request
-	 * @return
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param request リストア情報
+	 * @return ストレージ情報
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudStorage restoreStorage(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") RestoreStorageRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -421,12 +383,12 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したストレージを削除します。
 	 * 
-	 * @param regionName リージョン名。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param storageId ストレージ Id。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	void removeStorage(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "storageId") String storageId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -434,13 +396,13 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したストレージを取得します。
 	 * 
-	 * @param regionName リージョン名。
-	 * @param storageId ストレージ Id。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param storageId ストレージ ID。
 	 * @return ストレージ情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudStorage getStorage(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region,  @WebParam(name = "storageId") String storageId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -448,12 +410,12 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したリージョンに登録されているストレージの一覧を取得します。
 	 * 
-	 * @param regionName リージョン名。
-	 * @return ストレージ情報。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @return ストレージ情報一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	List<CloudStorage> getStoragesByRegion(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -461,6 +423,7 @@ public interface CloudEndpoint {
 	/**
 	 * 選択可能なストレージ種別の一覧を取得します。
 	 * 
+	 * @param cloudServiceId クラウドサービス ID。
 	 * @return ストレージ種別。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
@@ -470,14 +433,15 @@ public interface CloudEndpoint {
 	List<String> getStorageFlavorsByService(@WebParam(name = "cloudServiceId") String cloudServiceId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * 指定したストレージのバックアップ情報を取得します。
+	 * 指定したストレージのバックアップを作成します。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param request ストレージバックアップ作成情報。
 	 * @return ストレージバックアップ情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudStorageBackup addStorageBackup(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") CreateStorageBackupRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -485,12 +449,12 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したストレージのバックアップ情報を削除します。
 	 * 
-	 * @param regionName リージョン名。
-	 * @param snapshotId スナップショット Id。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param storageBackupId ストレージバックアップ ID。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	void removeStorageBackup(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "storageBackupId") String storageBackupId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -498,13 +462,13 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したストレージバックアップの情報を取得します。
 	 * 
-	 * @param regionName リージョン名。
-	 * @param snapshotId スナップショット Id。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param storageBackupId ストレージバックアップ ID。
 	 * @return ストレージバックアップ情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudStorageBackup getStorageBackup(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "storageBackupId") String storageBackupId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -512,12 +476,12 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したリージョンに登録されているストレージバックアップ情報の一覧を取得します。
 	 * 
-	 * @param regionName リージョン名。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @return ストレージバックアップ情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	List<CloudStorageBackup> getStorageBackupsByRegion(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -525,12 +489,13 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したインスタンスのバックアップ情報を取得します。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param request クラウドインスタンスバックアップ作成情報。
 	 * @return クラウドインスタンスバックアップ情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudInstanceBackup addInstanceBackup(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "request") CreateInstanceBackupRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -538,12 +503,12 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したインスタンスのバックアップ情報を削除します。
 	 * 
-	 * @param regionName リージョン名。
-	 * @param imageId イメージ Id。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param instanceBackupId インスタンスバックアップ ID。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	void removeInstanceBackup(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "instanceBackupId") String instanceBackupId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -551,13 +516,13 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したインスタンスのバックアップ情報を取得します。
 	 * 
-	 * @param regionName リージョン名。
-	 * @param imageId イメージ Id。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @param instanceBackupId インスタンスバックアップ ID。
 	 * @return クラウドインスタンスバックアップ情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudInstanceBackup getInstanceBackup(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region, @WebParam(name = "instanceBackupId") String instanceBackupId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -565,12 +530,12 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したリージョンに登録されているインスタンスバックアップ情報のリストを取得します。
 	 * 
-	 * @param regionName リージョン名。
-	 * @return クラウドインスタンスバックアップ情報。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
+	 * @return クラウドインスタンスバックアップ情報一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	List<CloudInstanceBackup> getInstanceBackupsByRegion(@WebParam(name = "roleId") String roleId, @WebParam(name = "region") String region) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -578,11 +543,12 @@ public interface CloudEndpoint {
 	/**
 	 * ノードと紐づいていないインスタンスにノードを紐づけます。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param request ノード登録情報。
 	 * @return クラウドインスタンス情報。
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 * @throws CloudManagerFault
 	 */
 	@WebMethod
@@ -591,11 +557,11 @@ public interface CloudEndpoint {
 	/**
 	 * ノードに紐づいたインスタンスで、既に EC2 インスタンスが削除されているインスタンスを削除します。
 	 * 
-	 * @param regionName リージョン名。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param region リージョン名。
 	 * @param instanceId インスタンス Id。
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 * @throws CloudManagerFault
 	 */
 	@WebMethod
@@ -604,12 +570,12 @@ public interface CloudEndpoint {
 	/**
 	 * テンプレートを追加します。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
 	 * @param template テンプレート情報。
 	 * @return テンプレート情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudTemplate addTemplate(@WebParam(name = "roleId") String roleId, @WebParam(name = "request") CreateTemplateRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -617,11 +583,11 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したテンプレートを削除します。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
 	 * @param templateId テンプレート Id。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	void removeTemplate(@WebParam(name = "roleId") String roleId, @WebParam(name = "templateId") String templateId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -629,11 +595,12 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したテンプレートを更新します。
 	 * 
+	 * @param roleId クラウドユーザーに紐づくロール ID。
 	 * @param template テンプレート情報。
+	 * @return テンプレート情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudTemplate modifyTemplate(@WebParam(name = "roleId") String roleId, @WebParam(name = "request") ModifyTemplateRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -641,12 +608,12 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したテンプレートを取得します。
 	 * 
-	 * @param templateId テンプレート Id。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @param templateId テンプレート ID。
 	 * @return テンプレート情報。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
-	 * @throws ValidationFault
 	 */
 	@WebMethod
 	CloudTemplate getTemplate(@WebParam(name = "roleId") String roleId, @WebParam(name = "templateId") String templateId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
@@ -654,7 +621,8 @@ public interface CloudEndpoint {
 	/**
 	 * 実行ユーザが参照可能な全てのテンプレートを取得します。
 	 * 
-	 * @return テンプレート情報。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @return テンプレート情報一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
@@ -665,16 +633,17 @@ public interface CloudEndpoint {
 	/**
 	 * テンプレートに設定可能なスクリプトの一覧を取得します。
 	 * 
-	 * @return スクリプト。
+	 * @param roleId クラウドユーザーに紐づくロール ID。
+	 * @return スクリプト一覧。
 	 * @throws CloudManagerFault
 	 */
 	@WebMethod
 	List<String> getTemplateScripts(@WebParam(name = "roleId") String roleId) throws CloudManagerFault;
 
 	/**
-	 * クラウドリソースグループを作成します。。
+	 * アカウントリソースを作成します。。
 	 * 
-	 * @param request クラウドリソースグループ情報。
+	 * @param request アカウントリソース情報。
 	 * @return 作成されたアカウントリソース。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
@@ -684,9 +653,9 @@ public interface CloudEndpoint {
 	CloudAccountResource addAccountResource(@WebParam(name = "request") CreateAccountResourceRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * クラウドリソースグループを変更します。
+	 * 指定したアカウントリソースを変更します。
 	 * 
-	 * @param request クラウドリソースグループ情報。
+	 * @param request アカウントリソース情報。
 	 * @return 変更後のアカウントリソース。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
@@ -696,9 +665,9 @@ public interface CloudEndpoint {
 	CloudAccountResource modifyAccountResource(@WebParam(name = "request") ModifyAccountResourceRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * クラウドリソースグループを変更します。
+	 * 指定したアカウントリソースの課金設定を変更します。
 	 * 
-	 * @param request クラウドリソースグループ情報。
+	 * @param request アカウントリソース情報。
 	 * @return 変更後のアカウントリソース。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
@@ -708,9 +677,9 @@ public interface CloudEndpoint {
 	CloudAccountResource modifyAccountBillingDetail(@WebParam(name = "request") ModifyAccountBillingDetailRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * クラウドリソースグループを削除します。
+	 * 指定したアカウントリソースを削除します。
 	 * 
-	 * @param cloudResourceGroupId クラウドリソースグループ Id。
+	 * @param accountResourceId アカウントリソース ID。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
@@ -719,9 +688,10 @@ public interface CloudEndpoint {
 	void removeAccountResource(@WebParam(name = "accountResourceId") String accountResourceId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 
 	/**
-	 * クラウドリソースグループを取得します。
+	 * 指定したアカウントリソースを取得する。
 	 * 
-	 * @param cloudResourceGroupId クラウドリソースグループ Id。
+	 * @param accountResourceId アカウントリソース ID。
+	 * @return アカウントリソース。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
@@ -732,6 +702,7 @@ public interface CloudEndpoint {
 	/**
 	 * アカウントリソースの一覧を取得します。
 	 * 
+	 * @return アカウントリソースの一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
@@ -742,7 +713,8 @@ public interface CloudEndpoint {
 	/**
 	 * 指定したクラウドサービスに紐付くリージョンの一覧を取得します。
 	 * 
-	 * @param cloudServiceId クラウドサービス Id。
+	 * @param cloudServiceId クラウドサービス ID。
+	 * @return リージョン一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
@@ -753,7 +725,8 @@ public interface CloudEndpoint {
 	/**
 	 * クラウドサービスを取得します。
 	 * 
-	 * @param cloudServiceId クラウドサービス Id。
+	 * @param cloudServiceId クラウドサービス ID。
+	 * @return クラウドサービス。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
@@ -764,6 +737,7 @@ public interface CloudEndpoint {
 	/**
 	 * クラウドサービスの一覧を取得します。
 	 * 
+	 * @return クラウドサービスの一覧。
 	 * @throws CloudManagerFault
 	 * @throws InvalidUserPass
 	 * @throws InvalidRole
@@ -771,12 +745,38 @@ public interface CloudEndpoint {
 	@WebMethod
 	List<CloudService> getAllCloudServices() throws CloudManagerFault, InvalidUserPass, InvalidRole;
 	
+	/**
+	 * クラウド課金監視のターゲットになるサービスの一覧を取得する。
+	 * 
+	 * @param accountResourceId アカウントリソース ID。
+	 * @return クラウド課金監視のターゲット一覧。
+	 * @throws CloudManagerFault
+	 * @throws InvalidUserPass
+	 * @throws InvalidRole
+	 */
 	@WebMethod
 	List<String> getCloudServicesForBilling(@WebParam(name = "accountResourceId") String accountResourceId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 	
+	/**
+	 * マネージャからの呼び出し待機中エージェントに対して、通信を開始する。
+	 * 
+	 * @param facilityId ファシリティ ID。
+	 * @throws CloudManagerFault
+	 * @throws InvalidUserPass
+	 * @throws InvalidRole
+	 */
 	@WebMethod
 	void establishAgentConnection(@WebParam(name = "facilityId") String facilityId) throws CloudManagerFault, InvalidUserPass, InvalidRole;
 	
+	/**
+	 * クラウドユーザーに紐付け可能なロールの一覧を取得する。
+	 * 戻される結果は、現在のアカウントが利用可能なロールの一覧から、既に紐付けられているロールを除外した内容になる。
+	 * 
+	 * @return クラウドユーザーに紐付け可能なロールの一覧。
+	 * @throws CloudManagerFault
+	 * @throws InvalidUserPass
+	 * @throws InvalidRole
+	 */
 	@WebMethod
 	List<AvailableRole> getAvailableRoles() throws CloudManagerFault, InvalidUserPass, InvalidRole;
 }
\ No newline at end of file
