@@ -1,15 +1,16 @@
 /*
-TTデータの澤井TTデータの澤井Copyright (C) 2013 NTT DATA Corporation
- 
+Copyright (C) 2013 NTT DATA Corporation
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
-*/
+ */
+
 package com.clustercontrol.ws.cloud;
 
 import static com.clustercontrol.cloud.util.ResourceUtil.getResourceOperator;
@@ -25,8 +26,8 @@ import javax.persistence.Query;
 import javax.xml.ws.WebServiceContext;
 
 import com.clustercontrol.accesscontrol.bean.FunctionConstant;
-import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.SystemPrivilegeMode;
+import com.clustercontrol.accesscontrol.bean.RoleIdConstant;
 import com.clustercontrol.accesscontrol.model.RoleEntity;
 import com.clustercontrol.cloud.CloudManagerFault;
 import com.clustercontrol.cloud.ErrorCode;
@@ -73,11 +74,13 @@ import com.clustercontrol.cloud.factory.ICloudUserOperator;
 import com.clustercontrol.cloud.factory.IInstanceOperator;
 import com.clustercontrol.cloud.factory.IStorageOperator;
 import com.clustercontrol.cloud.factory.ITemplateOperator;
-import com.clustercontrol.cloud.factory.InstanceOperator;
+import com.clustercontrol.cloud.factory.RegistAgent;
 import com.clustercontrol.cloud.persistence.EntityManagerEx;
 import com.clustercontrol.cloud.registry.ObjectRegistryService;
-import com.clustercontrol.cloud.validation.AuthorizingValidator_remove_clouduser;
+import com.clustercontrol.cloud.validation.AuthorizingValidator_accountresource;
+import com.clustercontrol.cloud.validation.AuthorizingValidator_get_clouduser;
 import com.clustercontrol.cloud.validation.AuthorizingValidator_is_administrator;
+import com.clustercontrol.cloud.validation.AuthorizingValidator_remove_clouduser;
 import com.clustercontrol.cloud.validation.AuthorizingValidator_role;
 import com.clustercontrol.cloud.validation.AuthorizingValidator_role_region;
 import com.clustercontrol.cloud.validation.ModifiableAccountResource;
@@ -96,7 +99,6 @@ import com.clustercontrol.fault.InvalidSetting;
 import com.clustercontrol.fault.InvalidUserPass;
 import com.clustercontrol.repository.util.FacilityTreeCache;
 import com.clustercontrol.ws.cloud.security.HinemosAccessRight;
-import com.clustercontrol.ws.cloud.security.HinemosAccessRights;
 
 /**
  * クラウド管理オプション用のエンドポイント
@@ -108,7 +110,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	private WebServiceContext wsctx;
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.ADD})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	@ValidationGroup("addInstance")
 	public CloudInstance addInstance(
@@ -120,10 +122,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRights({
-		@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC),
-		@HinemosAccessRight(roleName=FunctionConstant.JOBMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE, SystemPrivilegeMode.EXEC}),
-		})
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.ADD})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	@ValidationGroup("addInstanceByTemplate")
 	public CloudInstance addInstanceByTemplate(
@@ -135,7 +134,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	@ValidationGroup("restoreInstance")
 	public CloudInstance restoreInstance(
@@ -147,7 +146,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public void removeInstance(
 			@ElementId("roleId") @Identity String roleId,
@@ -179,7 +178,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public InstanceStateChange startInstance(
 			@ElementId("roleId") @Identity String roleId,
@@ -190,7 +189,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public InstanceStateChange stopInstance(
 			@ElementId("roleId") @Identity String roleId,
@@ -201,7 +200,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.ADD})
 	public CloudUser addCloudUser(
 			@ElementId("CreateCloudUserRequest") @NotNull @Into CreateCloudUserRequest request
 			) throws CloudManagerFault, InvalidUserPass, InvalidRole {
@@ -213,11 +212,12 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	public List<CloudUser> getCloudUsersByAccountResource(
 			@ElementId("accountResourceId") @Identity String accountResourceId
 			) throws CloudManagerFault, InvalidUserPass, InvalidRole {
-		return ObjectRegistryService.registry().get(ICloudUserOperator.class).findCloudUserByAccountResource(accountResourceId);
+		return ObjectRegistryService.registry().get(ICloudUserOperator.class).findCloudUserByAccountResourceAndUserId(accountResourceId, SessionService.current().getHinemosCredential().getUserId());
 	}
 	
 	@Override
 	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.READ)
+	@CustomMethodValidation(AuthorizingValidator_get_clouduser.class)
 	public CloudUser getCloudUser(
 			@ElementId("cloudUserId") @Identity String cloudUserId
 			) throws CloudManagerFault, InvalidUserPass, InvalidRole {
@@ -225,7 +225,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_remove_clouduser.class)
 	public void removeCloudUser(
 			@ElementId("cloudUserId") @Identity String cloudUserId
@@ -234,7 +234,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	public CloudUser modifyCloudUser(@ElementId("ModifyCloudUserRequest") @NotNull @Into ModifyCloudUserRequest request) throws CloudManagerFault, InvalidUserPass, InvalidRole {
 		return ObjectRegistryService.registry().get(ICloudUserOperator.class).modifyCloudUser(request);
 	}
@@ -297,7 +297,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public void attachStorage(
 			@ElementId("roleId") @Identity String roleId,
@@ -310,7 +310,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public void detachStorage(
 			@ElementId("roleId") @Identity String roleId,
@@ -322,7 +322,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.ADD})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public CloudStorage addStorage(
 			@ElementId("roleId") @Identity String roleId,
@@ -333,7 +333,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public CloudStorage restoreStorage(
 			@ElementId("roleId") @Identity String roleId,
@@ -344,7 +344,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public void removeStorage(
 			@ElementId("roleId") @Identity String roleId,
@@ -376,7 +376,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public CloudStorageBackup addStorageBackup(
 			@ElementId("roleId") @Identity String roleId,
@@ -387,7 +387,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public void removeStorageBackup(
 			@ElementId("roleId") @Identity String roleId,
@@ -419,7 +419,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public CloudInstanceBackup addInstanceBackup(
 			@ElementId("roleId") @Identity String roleId,
@@ -430,7 +430,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public void removeInstanceBackup(
 			@ElementId("roleId") @Identity String roleId,
@@ -441,7 +441,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.READ)
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public CloudInstanceBackup getInstanceBackup(
 			@ElementId("roleId") @Identity String roleId,
@@ -452,7 +452,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.READ)
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public List<CloudInstanceBackup> getInstanceBackupsByRegion(
 			@ElementId("roleId") @Identity String roleId,
@@ -462,7 +462,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	@ValidationGroup("registNode")
 	public CloudInstance registNode(
@@ -474,7 +474,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_role_region.class)
 	public void unregistNode(
 			@ElementId("roleId") @Identity String roleId,
@@ -492,7 +492,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 //	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.ADD})
 	@CustomMethodValidation(AuthorizingValidator_role.class)
 	public CloudTemplate addTemplate(
 			@ElementId("roleId") @Identity String roleId,
@@ -502,7 +502,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_role.class)
 	public void removeTemplate(
 			@ElementId("roleId") @Identity String roleId,
@@ -512,7 +512,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.WRITE})
 	@CustomMethodValidation(AuthorizingValidator_role.class)
 	public CloudTemplate modifyTemplate(
 			@ElementId("roleId") @Identity String roleId,
@@ -548,7 +548,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.ADD, SystemPrivilegeMode.READ})
 	@CustomMethodValidation(AuthorizingValidator_is_administrator.class)
 	public CloudAccountResource addAccountResource(
 			@ElementId("CreateAccountResourceRequest") @NotNull @Into CreateAccountResourceRequest request
@@ -558,8 +558,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
-	@CustomMethodValidation(AuthorizingValidator_is_administrator.class)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.WRITE, SystemPrivilegeMode.READ})
 	public CloudAccountResource modifyAccountResource(
 			@ElementId("ModifyAccountResourceRequest") @NotNull @Into ModifyAccountResourceRequest request
 			) throws CloudManagerFault, InvalidUserPass, InvalidRole {
@@ -567,8 +566,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
-	@CustomMethodValidation(AuthorizingValidator_is_administrator.class)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.EXEC, SystemPrivilegeMode.READ})
 	public CloudAccountResource modifyAccountBillingDetail(
 			@ElementId("ModifyAccountBillingDetailRequest") @NotNull @Into ModifyAccountBillingDetailRequest request)
 			throws CloudManagerFault, InvalidUserPass, InvalidRole {
@@ -576,7 +574,7 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 	}
 	
 	@Override
-	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.WRITE)
+	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right={SystemPrivilegeMode.WRITE, SystemPrivilegeMode.READ})
 	@CustomMethodValidation(AuthorizingValidator_is_administrator.class)
 	public void removeAccountResource(
 			@ElementId("accountResourceId") @NotNull @ModifiableAccountResource String accountResourceId)
@@ -661,12 +659,13 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 
 	@Override
 	@HinemosAccessRight(roleName=CLOUDMANAGEMENT, right=SystemPrivilegeMode.READ)
+	@CustomMethodValidation(AuthorizingValidator_accountresource.class)
 	public List<String> getCloudServicesForBilling(@ElementId("accountResourceId") @Identity String accountResourceId) throws CloudManagerFault, InvalidUserPass, InvalidRole {
 		return ObjectRegistryService.registry().get(IAccountResourceOperator.class).getCloudServicesForBilling(accountResourceId);
 	}
 
 	@Override
-	@HinemosAccessRight(roleName=FunctionConstant.REPOSITORY, right=SystemPrivilegeMode.EXEC)
+	@HinemosAccessRight(roleName=FunctionConstant.REPOSITORY, right={SystemPrivilegeMode.READ, SystemPrivilegeMode.EXEC})
 	public void establishAgentConnection(
 			@ElementId("facilityId") @Identity String facilityId
 			) throws CloudManagerFault, InvalidUserPass, InvalidRole {
@@ -691,15 +690,11 @@ public class CloudEndpointImpl implements CloudEndpoint, IWebServiceBase, CloudR
 		
 		if (!accessable) throw ErrorCode.NODE_DO_NOT_BE_ACCESSIBLE.cloudManagerFault(facilityId);
 		
-		InstanceOperator.asyncRegistAgent(facilityId);
+		RegistAgent.asyncRegistAgent(facilityId);
 	}
 	
 	@Override
-	@HinemosAccessRights(
-			{
-				@HinemosAccessRight(roleName=FunctionConstant.REPOSITORY, right=SystemPrivilegeMode.READ),
-				@HinemosAccessRight(roleName=FunctionConstant.CLOUDMANAGEMENT, right=SystemPrivilegeMode.READ)
-			})
+	@HinemosAccessRight(roleName=FunctionConstant.CLOUDMANAGEMENT, right=SystemPrivilegeMode.READ)
 	public List<AvailableRole> getAvailableRoles() throws CloudManagerFault, InvalidUserPass, InvalidRole {
 		Query query = null;
 		List<String> excludes = Arrays.asList(RoleIdConstant.INTERNAL, RoleIdConstant.HINEMOS_MODULE);
